Class: Norbelys::DomainAge
- Inherits:
-
Object
- Object
- Norbelys::DomainAge
- Defined in:
- lib/norbelys/models/domain_age.rb
Overview
Registration and observed-sending age for a sending domain.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#age_days ⇒ Object
Returns the value of attribute age_days.
-
#checked_at ⇒ Object
Returns the value of attribute checked_at.
-
#first_healthy_at ⇒ Object
Returns the value of attribute first_healthy_at.
-
#first_seen_sending_at ⇒ Object
Returns the value of attribute first_seen_sending_at.
-
#registered_at ⇒ Object
Returns the value of attribute registered_at.
-
#sending_age_days ⇒ Object
Returns the value of attribute sending_age_days.
-
#source ⇒ Object
Where the age came from:
rdap,sending_history, orunknown.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainAge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainAge
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/norbelys/models/domain_age.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::DomainAge` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::DomainAge`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'age_days') self.age_days = attributes[:'age_days'] else self.age_days = nil end if attributes.key?(:'checked_at') self.checked_at = attributes[:'checked_at'] end if attributes.key?(:'first_healthy_at') self.first_healthy_at = attributes[:'first_healthy_at'] end if attributes.key?(:'first_seen_sending_at') self.first_seen_sending_at = attributes[:'first_seen_sending_at'] end if attributes.key?(:'registered_at') self.registered_at = attributes[:'registered_at'] end if attributes.key?(:'sending_age_days') self.sending_age_days = attributes[:'sending_age_days'] else self.sending_age_days = nil end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end end |
Instance Attribute Details
#age_days ⇒ Object
Returns the value of attribute age_days.
19 20 21 |
# File 'lib/norbelys/models/domain_age.rb', line 19 def age_days @age_days end |
#checked_at ⇒ Object
Returns the value of attribute checked_at.
21 22 23 |
# File 'lib/norbelys/models/domain_age.rb', line 21 def checked_at @checked_at end |
#first_healthy_at ⇒ Object
Returns the value of attribute first_healthy_at.
23 24 25 |
# File 'lib/norbelys/models/domain_age.rb', line 23 def first_healthy_at @first_healthy_at end |
#first_seen_sending_at ⇒ Object
Returns the value of attribute first_seen_sending_at.
25 26 27 |
# File 'lib/norbelys/models/domain_age.rb', line 25 def first_seen_sending_at @first_seen_sending_at end |
#registered_at ⇒ Object
Returns the value of attribute registered_at.
27 28 29 |
# File 'lib/norbelys/models/domain_age.rb', line 27 def registered_at @registered_at end |
#sending_age_days ⇒ Object
Returns the value of attribute sending_age_days.
29 30 31 |
# File 'lib/norbelys/models/domain_age.rb', line 29 def sending_age_days @sending_age_days end |
#source ⇒ Object
Where the age came from: rdap, sending_history, or unknown.
32 33 34 |
# File 'lib/norbelys/models/domain_age.rb', line 32 def source @source end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/norbelys/models/domain_age.rb', line 264 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Norbelys.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/norbelys/models/domain_age.rb', line 70 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/norbelys/models/domain_age.rb', line 57 def self.attribute_map { :'age_days' => :'ageDays', :'checked_at' => :'checkedAt', :'first_healthy_at' => :'firstHealthyAt', :'first_seen_sending_at' => :'firstSeenSendingAt', :'registered_at' => :'registeredAt', :'sending_age_days' => :'sendingAgeDays', :'source' => :'source' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/norbelys/models/domain_age.rb', line 240 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 93 94 95 96 97 |
# File 'lib/norbelys/models/domain_age.rb', line 88 def self.openapi_nullable Set.new([ :'age_days', :'checked_at', :'first_healthy_at', :'first_seen_sending_at', :'registered_at', :'sending_age_days', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/norbelys/models/domain_age.rb', line 75 def self.openapi_types { :'age_days' => :'Integer', :'checked_at' => :'Object', :'first_healthy_at' => :'Object', :'first_seen_sending_at' => :'Object', :'registered_at' => :'Object', :'sending_age_days' => :'Integer', :'source' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/norbelys/models/domain_age.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && age_days == o.age_days && checked_at == o.checked_at && first_healthy_at == o.first_healthy_at && first_seen_sending_at == o.first_seen_sending_at && registered_at == o.registered_at && sending_age_days == o.sending_age_days && source == o.source end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/norbelys/models/domain_age.rb', line 335 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/norbelys/models/domain_age.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/norbelys/models/domain_age.rb', line 233 def hash [age_days, checked_at, first_healthy_at, first_seen_sending_at, registered_at, sending_age_days, source].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/norbelys/models/domain_age.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @age_days < 0 invalid_properties.push('invalid value for "age_days", must be greater than or equal to 0.') end if @sending_age_days < 0 invalid_properties.push('invalid value for "sending_age_days", must be greater than or equal to 0.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
311 312 313 |
# File 'lib/norbelys/models/domain_age.rb', line 311 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/norbelys/models/domain_age.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
305 306 307 |
# File 'lib/norbelys/models/domain_age.rb', line 305 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 179 |
# File 'lib/norbelys/models/domain_age.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @age_days < 0 return false if @sending_age_days < 0 return false if @source.nil? source_validator = EnumAttributeValidator.new('String', ["rdap", "sending_history", "unknown"]) return false unless source_validator.valid?(@source) true end |