Class: Norbelys::DomainMonitoring
- Inherits:
-
Object
- Object
- Norbelys::DomainMonitoring
- Defined in:
- lib/norbelys/models/domain_monitoring.rb
Overview
DMARC monitoring summary and report-collection status for a monitoring domain.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#collection_status ⇒ Object
Where report collection stands: "waiting" = the
_dmarcrua record isn't pointing to us yet; "live" = published to us, awaiting the first report; "collecting" = reports are arriving. -
#dmarc_policy ⇒ Object
Returns the value of attribute dmarc_policy.
-
#kind ⇒ Object
"sending" = one of our own sending domains; "external" = monitor-only.
-
#last_report_at ⇒ Object
Returns the value of attribute last_report_at.
-
#pass_rate7d ⇒ Object
Returns the value of attribute pass_rate7d.
-
#record_to_publish ⇒ Object
Returns the value of attribute record_to_publish.
-
#sending_domain_id ⇒ Object
Returns the value of attribute sending_domain_id.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainMonitoring
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainMonitoring
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::DomainMonitoring` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::DomainMonitoring`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'collection_status') self.collection_status = attributes[:'collection_status'] else self.collection_status = nil end if attributes.key?(:'dmarc_policy') self.dmarc_policy = attributes[:'dmarc_policy'] else self.dmarc_policy = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'last_report_at') self.last_report_at = attributes[:'last_report_at'] end if attributes.key?(:'pass_rate7d') self.pass_rate7d = attributes[:'pass_rate7d'] else self.pass_rate7d = nil end if attributes.key?(:'record_to_publish') self.record_to_publish = attributes[:'record_to_publish'] else self.record_to_publish = nil end if attributes.key?(:'sending_domain_id') self.sending_domain_id = attributes[:'sending_domain_id'] else self.sending_domain_id = nil end end |
Instance Attribute Details
#collection_status ⇒ Object
Where report collection stands: "waiting" = the _dmarc rua record isn't pointing to us yet; "live" = published to us, awaiting the first report; "collecting" = reports are arriving.
20 21 22 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 20 def collection_status @collection_status end |
#dmarc_policy ⇒ Object
Returns the value of attribute dmarc_policy.
22 23 24 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 22 def dmarc_policy @dmarc_policy end |
#kind ⇒ Object
"sending" = one of our own sending domains; "external" = monitor-only.
25 26 27 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 25 def kind @kind end |
#last_report_at ⇒ Object
Returns the value of attribute last_report_at.
27 28 29 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 27 def last_report_at @last_report_at end |
#pass_rate7d ⇒ Object
Returns the value of attribute pass_rate7d.
29 30 31 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 29 def pass_rate7d @pass_rate7d end |
#record_to_publish ⇒ Object
Returns the value of attribute record_to_publish.
31 32 33 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 31 def record_to_publish @record_to_publish end |
#sending_domain_id ⇒ Object
Returns the value of attribute sending_domain_id.
33 34 35 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 33 def sending_domain_id @sending_domain_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 293 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Norbelys.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 71 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 58 def self.attribute_map { :'collection_status' => :'collectionStatus', :'dmarc_policy' => :'dmarcPolicy', :'kind' => :'kind', :'last_report_at' => :'lastReportAt', :'pass_rate7d' => :'passRate7d', :'record_to_publish' => :'recordToPublish', :'sending_domain_id' => :'sendingDomainId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 269 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 93 94 95 96 97 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 89 def self.openapi_nullable Set.new([ :'dmarc_policy', :'last_report_at', :'pass_rate7d', :'record_to_publish', :'sending_domain_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 76 def self.openapi_types { :'collection_status' => :'String', :'dmarc_policy' => :'String', :'kind' => :'String', :'last_report_at' => :'Object', :'pass_rate7d' => :'Float', :'record_to_publish' => :'DmarcRecordToPublish', :'sending_domain_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && collection_status == o.collection_status && dmarc_policy == o.dmarc_policy && kind == o.kind && last_report_at == o.last_report_at && pass_rate7d == o.pass_rate7d && record_to_publish == o.record_to_publish && sending_domain_id == o.sending_domain_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 364 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
256 257 258 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 256 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 262 def hash [collection_status, dmarc_policy, kind, last_report_at, pass_rate7d, record_to_publish, sending_domain_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @collection_status.nil? invalid_properties.push('invalid value for "collection_status", collection_status cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @pass_rate7d > 1 invalid_properties.push('invalid value for "pass_rate7d", must be smaller than or equal to 1.') end if @pass_rate7d < 0 invalid_properties.push('invalid value for "pass_rate7d", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
340 341 342 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 340 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 346 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
334 335 336 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 334 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/norbelys/models/domain_monitoring.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @collection_status.nil? collection_status_validator = EnumAttributeValidator.new('String', ["waiting", "live", "collecting"]) return false unless collection_status_validator.valid?(@collection_status) dmarc_policy_validator = EnumAttributeValidator.new('String', ["none", "quarantine", "reject"]) return false unless dmarc_policy_validator.valid?(@dmarc_policy) return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["sending", "external"]) return false unless kind_validator.valid?(@kind) return false if @pass_rate7d > 1 return false if @pass_rate7d < 0 true end |