Class: Norbelys::Field

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/field.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Field

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/norbelys/models/field.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::Field` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::Field`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'archived_at')
    self.archived_at = attributes[:'archived_at']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'is_filterable')
    self.is_filterable = attributes[:'is_filterable']
  else
    self.is_filterable = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  else
    self.label = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'options')
    if (value = attributes[:'options']).is_a?(Array)
      self.options = value
    end
  else
    self.options = nil
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  else
    self.order = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#archived_atObject

Returns the value of attribute archived_at.



18
19
20
# File 'lib/norbelys/models/field.rb', line 18

def archived_at
  @archived_at
end

#codeObject

The merge tag and storage key, templated as {{ code }}.



21
22
23
# File 'lib/norbelys/models/field.rb', line 21

def code
  @code
end

#created_atObject

Returns the value of attribute created_at.



23
24
25
# File 'lib/norbelys/models/field.rb', line 23

def created_at
  @created_at
end

#idObject

The field id.



26
27
28
# File 'lib/norbelys/models/field.rb', line 26

def id
  @id
end

#is_filterableObject

Whether this field is offered as a segment/list filter.



29
30
31
# File 'lib/norbelys/models/field.rb', line 29

def is_filterable
  @is_filterable
end

#labelObject

The human-readable display name for the field.



32
33
34
# File 'lib/norbelys/models/field.rb', line 32

def label
  @label
end

#objectObject

Returns the value of attribute object.



34
35
36
# File 'lib/norbelys/models/field.rb', line 34

def object
  @object
end

#optionsObject

Returns the value of attribute options.



36
37
38
# File 'lib/norbelys/models/field.rb', line 36

def options
  @options
end

#orderObject

Display order among custom fields (lower = first).



39
40
41
# File 'lib/norbelys/models/field.rb', line 39

def order
  @order
end

#typeObject

Returns the value of attribute type.



41
42
43
# File 'lib/norbelys/models/field.rb', line 41

def type
  @type
end

#updated_atObject

Returns the value of attribute updated_at.



43
44
45
# File 'lib/norbelys/models/field.rb', line 43

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/norbelys/models/field.rb', line 314

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/norbelys/models/field.rb', line 85

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/norbelys/models/field.rb', line 68

def self.attribute_map
  {
    :'archived_at' => :'archivedAt',
    :'code' => :'code',
    :'created_at' => :'createdAt',
    :'id' => :'id',
    :'is_filterable' => :'isFilterable',
    :'label' => :'label',
    :'object' => :'object',
    :'options' => :'options',
    :'order' => :'order',
    :'type' => :'type',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/norbelys/models/field.rb', line 290

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
114
115
# File 'lib/norbelys/models/field.rb', line 107

def self.openapi_nullable
  Set.new([
    :'archived_at',
    :'created_at',
    :'object',
    :'options',
    :'updated_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/norbelys/models/field.rb', line 90

def self.openapi_types
  {
    :'archived_at' => :'Object',
    :'code' => :'String',
    :'created_at' => :'Object',
    :'id' => :'String',
    :'is_filterable' => :'Boolean',
    :'label' => :'String',
    :'object' => :'Object',
    :'options' => :'Array<String>',
    :'order' => :'Integer',
    :'type' => :'FieldType',
    :'updated_at' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/norbelys/models/field.rb', line 259

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      archived_at == o.archived_at &&
      code == o.code &&
      created_at == o.created_at &&
      id == o.id &&
      is_filterable == o.is_filterable &&
      label == o.label &&
      object == o.object &&
      options == o.options &&
      order == o.order &&
      type == o.type &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/norbelys/models/field.rb', line 385

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


277
278
279
# File 'lib/norbelys/models/field.rb', line 277

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



283
284
285
# File 'lib/norbelys/models/field.rb', line 283

def hash
  [archived_at, code, created_at, id, is_filterable, label, object, options, order, type, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/norbelys/models/field.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @is_filterable.nil?
    invalid_properties.push('invalid value for "is_filterable", is_filterable cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  if @order.nil?
    invalid_properties.push('invalid value for "order", order cannot be nil.')
  end

  if @order < 0
    invalid_properties.push('invalid value for "order", must be greater than or equal to 0.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
# File 'lib/norbelys/models/field.rb', line 361

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/norbelys/models/field.rb', line 367

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



355
356
357
# File 'lib/norbelys/models/field.rb', line 355

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
237
238
239
240
241
# File 'lib/norbelys/models/field.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @code.nil?
  return false if @id.nil?
  return false if @is_filterable.nil?
  return false if @label.nil?
  return false if @order.nil?
  return false if @order < 0
  return false if @type.nil?
  true
end