Class: Norbelys::InboundMessage

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/inbound_message.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InboundMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/norbelys/models/inbound_message.rb', line 145

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::InboundMessage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::InboundMessage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'contact_email')
    self.contact_email = attributes[:'contact_email']
  else
    self.contact_email = nil
  end

  if attributes.key?(:'contact_name')
    self.contact_name = attributes[:'contact_name']
  else
    self.contact_name = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'occurred_at')
    self.occurred_at = attributes[:'occurred_at']
  end

  if attributes.key?(:'person_id')
    self.person_id = attributes[:'person_id']
  else
    self.person_id = nil
  end

  if attributes.key?(:'sender_id')
    self.sender_id = attributes[:'sender_id']
  else
    self.sender_id = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'thread_id')
    self.thread_id = attributes[:'thread_id']
  else
    self.thread_id = nil
  end

  if attributes.key?(:'assignee_id')
    self.assignee_id = attributes[:'assignee_id']
  else
    self.assignee_id = nil
  end

  if attributes.key?(:'body_html')
    self.body_html = attributes[:'body_html']
  else
    self.body_html = nil
  end

  if attributes.key?(:'body_text')
    self.body_text = attributes[:'body_text']
  else
    self.body_text = nil
  end

  if attributes.key?(:'classification')
    self.classification = attributes[:'classification']
  else
    self.classification = nil
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  else
    self.direction = nil
  end

  if attributes.key?(:'from_email')
    self.from_email = attributes[:'from_email']
  else
    self.from_email = nil
  end

  if attributes.key?(:'is_read')
    self.is_read = attributes[:'is_read']
  else
    self.is_read = nil
  end
end

Instance Attribute Details

#assignee_idObject

Returns the value of attribute assignee_id.



37
38
39
# File 'lib/norbelys/models/inbound_message.rb', line 37

def assignee_id
  @assignee_id
end

#body_htmlObject

Returns the value of attribute body_html.



39
40
41
# File 'lib/norbelys/models/inbound_message.rb', line 39

def body_html
  @body_html
end

#body_textObject

Returns the value of attribute body_text.



41
42
43
# File 'lib/norbelys/models/inbound_message.rb', line 41

def body_text
  @body_text
end

#classificationObject

Triage class: interested, out_of_office, not_interested, auto_reply, bounce, complaint, unsubscribe, or uncategorized.



44
45
46
# File 'lib/norbelys/models/inbound_message.rb', line 44

def classification
  @classification
end

#contact_emailObject

Returns the value of attribute contact_email.



18
19
20
# File 'lib/norbelys/models/inbound_message.rb', line 18

def contact_email
  @contact_email
end

#contact_nameObject

Returns the value of attribute contact_name.



20
21
22
# File 'lib/norbelys/models/inbound_message.rb', line 20

def contact_name
  @contact_name
end

#directionObject

Returns the value of attribute direction.



46
47
48
# File 'lib/norbelys/models/inbound_message.rb', line 46

def direction
  @direction
end

#from_emailObject

Returns the value of attribute from_email.



48
49
50
# File 'lib/norbelys/models/inbound_message.rb', line 48

def from_email
  @from_email
end

#idObject

The message id.



23
24
25
# File 'lib/norbelys/models/inbound_message.rb', line 23

def id
  @id
end

#is_readObject

Whether the reply has been read.



51
52
53
# File 'lib/norbelys/models/inbound_message.rb', line 51

def is_read
  @is_read
end

#objectObject

Returns the value of attribute object.



25
26
27
# File 'lib/norbelys/models/inbound_message.rb', line 25

def object
  @object
end

#occurred_atObject

Returns the value of attribute occurred_at.



27
28
29
# File 'lib/norbelys/models/inbound_message.rb', line 27

def occurred_at
  @occurred_at
end

#person_idObject

Returns the value of attribute person_id.



29
30
31
# File 'lib/norbelys/models/inbound_message.rb', line 29

def person_id
  @person_id
end

#sender_idObject

Returns the value of attribute sender_id.



31
32
33
# File 'lib/norbelys/models/inbound_message.rb', line 31

def sender_id
  @sender_id
end

#subjectObject

Returns the value of attribute subject.



33
34
35
# File 'lib/norbelys/models/inbound_message.rb', line 33

def subject
  @subject
end

#thread_idObject

Returns the value of attribute thread_id.



35
36
37
# File 'lib/norbelys/models/inbound_message.rb', line 35

def thread_id
  @thread_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/norbelys/models/inbound_message.rb', line 355

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/norbelys/models/inbound_message.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/norbelys/models/inbound_message.rb', line 76

def self.attribute_map
  {
    :'contact_email' => :'contactEmail',
    :'contact_name' => :'contactName',
    :'id' => :'id',
    :'object' => :'object',
    :'occurred_at' => :'occurredAt',
    :'person_id' => :'personId',
    :'sender_id' => :'senderId',
    :'subject' => :'subject',
    :'thread_id' => :'threadId',
    :'assignee_id' => :'assigneeId',
    :'body_html' => :'bodyHtml',
    :'body_text' => :'bodyText',
    :'classification' => :'classification',
    :'direction' => :'direction',
    :'from_email' => :'fromEmail',
    :'is_read' => :'isRead'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/norbelys/models/inbound_message.rb', line 331

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/norbelys/models/inbound_message.rb', line 125

def self.openapi_nullable
  Set.new([
    :'contact_email',
    :'contact_name',
    :'object',
    :'occurred_at',
    :'person_id',
    :'sender_id',
    :'subject',
    :'thread_id',
    :'assignee_id',
    :'body_html',
    :'body_text',
    :'direction',
    :'from_email',
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/norbelys/models/inbound_message.rb', line 103

def self.openapi_types
  {
    :'contact_email' => :'String',
    :'contact_name' => :'String',
    :'id' => :'String',
    :'object' => :'Object',
    :'occurred_at' => :'Object',
    :'person_id' => :'String',
    :'sender_id' => :'String',
    :'subject' => :'String',
    :'thread_id' => :'String',
    :'assignee_id' => :'String',
    :'body_html' => :'String',
    :'body_text' => :'String',
    :'classification' => :'String',
    :'direction' => :'Object',
    :'from_email' => :'String',
    :'is_read' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/norbelys/models/inbound_message.rb', line 295

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      contact_email == o.contact_email &&
      contact_name == o.contact_name &&
      id == o.id &&
      object == o.object &&
      occurred_at == o.occurred_at &&
      person_id == o.person_id &&
      sender_id == o.sender_id &&
      subject == o.subject &&
      thread_id == o.thread_id &&
      assignee_id == o.assignee_id &&
      body_html == o.body_html &&
      body_text == o.body_text &&
      classification == o.classification &&
      direction == o.direction &&
      from_email == o.from_email &&
      is_read == o.is_read
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/norbelys/models/inbound_message.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/norbelys/models/inbound_message.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



324
325
326
# File 'lib/norbelys/models/inbound_message.rb', line 324

def hash
  [contact_email, contact_name, id, object, occurred_at, person_id, sender_id, subject, thread_id, assignee_id, body_html, body_text, classification, direction, from_email, is_read].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/norbelys/models/inbound_message.rb', line 253

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @classification.nil?
    invalid_properties.push('invalid value for "classification", classification cannot be nil.')
  end

  if @is_read.nil?
    invalid_properties.push('invalid value for "is_read", is_read cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
# File 'lib/norbelys/models/inbound_message.rb', line 402

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/norbelys/models/inbound_message.rb', line 408

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/norbelys/models/inbound_message.rb', line 396

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



273
274
275
276
277
278
279
280
281
# File 'lib/norbelys/models/inbound_message.rb', line 273

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @classification.nil?
  classification_validator = EnumAttributeValidator.new('String', ["interested", "out_of_office", "not_interested", "auto_reply", "bounce", "complaint", "unsubscribe", "uncategorized"])
  return false unless classification_validator.valid?(@classification)
  return false if @is_read.nil?
  true
end