Class: Norbelys::PersonDetail

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/person_detail.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PersonDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/norbelys/models/person_detail.rb', line 175

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::PersonDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::PersonDetail`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'archived_at')
    self.archived_at = attributes[:'archived_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'custom_fields')
    if (value = attributes[:'custom_fields']).is_a?(Hash)
      self.custom_fields = value
    end
  else
    self.custom_fields = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'email_domain')
    self.email_domain = attributes[:'email_domain']
  else
    self.email_domain = nil
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  else
    self.family_name = nil
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  else
    self.given_name = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  else
    self.import_id = nil
  end

  if attributes.key?(:'last_activity_at')
    self.last_activity_at = attributes[:'last_activity_at']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'private_notes')
    self.private_notes = attributes[:'private_notes']
  else
    self.private_notes = nil
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  else
    self.score = nil
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'telephone')
    self.telephone = attributes[:'telephone']
  else
    self.telephone = nil
  end

  if attributes.key?(:'telephones')
    if (value = attributes[:'telephones']).is_a?(Array)
      self.telephones = value
    end
  else
    self.telephones = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'enrollments')
    if (value = attributes[:'enrollments']).is_a?(Array)
      self.enrollments = value
    end
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'segments')
    if (value = attributes[:'segments']).is_a?(Array)
      self.segments = value
    end
  end

  if attributes.key?(:'timeline')
    if (value = attributes[:'timeline']).is_a?(Array)
      self.timeline = value
    end
  end
end

Instance Attribute Details

#archived_atObject

Returns the value of attribute archived_at.



18
19
20
# File 'lib/norbelys/models/person_detail.rb', line 18

def archived_at
  @archived_at
end

#created_atObject

Returns the value of attribute created_at.



20
21
22
# File 'lib/norbelys/models/person_detail.rb', line 20

def created_at
  @created_at
end

#custom_fieldsObject

Returns the value of attribute custom_fields.



22
23
24
# File 'lib/norbelys/models/person_detail.rb', line 22

def custom_fields
  @custom_fields
end

#emailObject

Returns the value of attribute email.



24
25
26
# File 'lib/norbelys/models/person_detail.rb', line 24

def email
  @email
end

#email_domainObject

Returns the value of attribute email_domain.



26
27
28
# File 'lib/norbelys/models/person_detail.rb', line 26

def email_domain
  @email_domain
end

#enrollmentsObject

Expansion: the person's enrollments across all campaigns.



58
59
60
# File 'lib/norbelys/models/person_detail.rb', line 58

def enrollments
  @enrollments
end

#family_nameObject

Returns the value of attribute family_name.



28
29
30
# File 'lib/norbelys/models/person_detail.rb', line 28

def family_name
  @family_name
end

#given_nameObject

Returns the value of attribute given_name.



30
31
32
# File 'lib/norbelys/models/person_detail.rb', line 30

def given_name
  @given_name
end

#groupsObject

Expansion: the static groups this person belongs to.



61
62
63
# File 'lib/norbelys/models/person_detail.rb', line 61

def groups
  @groups
end

#idObject

The person id.



33
34
35
# File 'lib/norbelys/models/person_detail.rb', line 33

def id
  @id
end

#import_idObject

Returns the value of attribute import_id.



35
36
37
# File 'lib/norbelys/models/person_detail.rb', line 35

def import_id
  @import_id
end

#last_activity_atObject

Returns the value of attribute last_activity_at.



37
38
39
# File 'lib/norbelys/models/person_detail.rb', line 37

def last_activity_at
  @last_activity_at
end

#objectObject

Returns the value of attribute object.



39
40
41
# File 'lib/norbelys/models/person_detail.rb', line 39

def object
  @object
end

#private_notesObject

Returns the value of attribute private_notes.



41
42
43
# File 'lib/norbelys/models/person_detail.rb', line 41

def private_notes
  @private_notes
end

#scoreObject

Returns the value of attribute score.



43
44
45
# File 'lib/norbelys/models/person_detail.rb', line 43

def score
  @score
end

#segmentsObject

Expansion: the dynamic segments this person currently matches.



64
65
66
# File 'lib/norbelys/models/person_detail.rb', line 64

def segments
  @segments
end

#sourceObject

Where the person came from: csv_import, manual, api, form, inbound, integration.



46
47
48
# File 'lib/norbelys/models/person_detail.rb', line 46

def source
  @source
end

#statusObject

Lifecycle status: active, replied, bounced, unsubscribed, finished.



49
50
51
# File 'lib/norbelys/models/person_detail.rb', line 49

def status
  @status
end

#telephoneObject

Returns the value of attribute telephone.



51
52
53
# File 'lib/norbelys/models/person_detail.rb', line 51

def telephone
  @telephone
end

#telephonesObject

Returns the value of attribute telephones.



53
54
55
# File 'lib/norbelys/models/person_detail.rb', line 53

def telephones
  @telephones
end

#timelineObject

Expansion: the person's merged sent + received messages, newest first.



67
68
69
# File 'lib/norbelys/models/person_detail.rb', line 67

def timeline
  @timeline
end

#updated_atObject

Returns the value of attribute updated_at.



55
56
57
# File 'lib/norbelys/models/person_detail.rb', line 55

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/norbelys/models/person_detail.rb', line 461

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



120
121
122
# File 'lib/norbelys/models/person_detail.rb', line 120

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/norbelys/models/person_detail.rb', line 92

def self.attribute_map
  {
    :'archived_at' => :'archivedAt',
    :'created_at' => :'createdAt',
    :'custom_fields' => :'customFields',
    :'email' => :'email',
    :'email_domain' => :'emailDomain',
    :'family_name' => :'familyName',
    :'given_name' => :'givenName',
    :'id' => :'id',
    :'import_id' => :'importId',
    :'last_activity_at' => :'lastActivityAt',
    :'object' => :'object',
    :'private_notes' => :'privateNotes',
    :'score' => :'score',
    :'source' => :'source',
    :'status' => :'status',
    :'telephone' => :'telephone',
    :'telephones' => :'telephones',
    :'updated_at' => :'updatedAt',
    :'enrollments' => :'enrollments',
    :'groups' => :'groups',
    :'segments' => :'segments',
    :'timeline' => :'timeline'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/norbelys/models/person_detail.rb', line 437

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/norbelys/models/person_detail.rb', line 153

def self.openapi_nullable
  Set.new([
    :'archived_at',
    :'created_at',
    :'custom_fields',
    :'email',
    :'email_domain',
    :'family_name',
    :'given_name',
    :'import_id',
    :'last_activity_at',
    :'object',
    :'private_notes',
    :'score',
    :'telephone',
    :'telephones',
    :'updated_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/norbelys/models/person_detail.rb', line 125

def self.openapi_types
  {
    :'archived_at' => :'Object',
    :'created_at' => :'Object',
    :'custom_fields' => :'Hash<String, Object>',
    :'email' => :'String',
    :'email_domain' => :'String',
    :'family_name' => :'String',
    :'given_name' => :'String',
    :'id' => :'String',
    :'import_id' => :'String',
    :'last_activity_at' => :'Object',
    :'object' => :'Object',
    :'private_notes' => :'String',
    :'score' => :'Integer',
    :'source' => :'String',
    :'status' => :'String',
    :'telephone' => :'String',
    :'telephones' => :'Array<String>',
    :'updated_at' => :'Object',
    :'enrollments' => :'Array<Enrollment>',
    :'groups' => :'Array<PersonGroupRef>',
    :'segments' => :'Array<PersonSegmentRef>',
    :'timeline' => :'Array<Message>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/norbelys/models/person_detail.rb', line 395

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      archived_at == o.archived_at &&
      created_at == o.created_at &&
      custom_fields == o.custom_fields &&
      email == o.email &&
      email_domain == o.email_domain &&
      family_name == o.family_name &&
      given_name == o.given_name &&
      id == o.id &&
      import_id == o.import_id &&
      last_activity_at == o.last_activity_at &&
      object == o.object &&
      private_notes == o.private_notes &&
      score == o.score &&
      source == o.source &&
      status == o.status &&
      telephone == o.telephone &&
      telephones == o.telephones &&
      updated_at == o.updated_at &&
      enrollments == o.enrollments &&
      groups == o.groups &&
      segments == o.segments &&
      timeline == o.timeline
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/norbelys/models/person_detail.rb', line 532

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


424
425
426
# File 'lib/norbelys/models/person_detail.rb', line 424

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



430
431
432
# File 'lib/norbelys/models/person_detail.rb', line 430

def hash
  [archived_at, created_at, custom_fields, email, email_domain, family_name, given_name, id, import_id, last_activity_at, object, private_notes, score, source, status, telephone, telephones, updated_at, enrollments, groups, segments, timeline].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/norbelys/models/person_detail.rb', line 317

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @score > 100
    invalid_properties.push('invalid value for "score", must be smaller than or equal to 100.')
  end

  if @score < 0
    invalid_properties.push('invalid value for "score", must be greater than or equal to 0.')
  end

  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



508
509
510
# File 'lib/norbelys/models/person_detail.rb', line 508

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



514
515
516
517
518
519
520
521
522
523
524
525
526
# File 'lib/norbelys/models/person_detail.rb', line 514

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



502
503
504
# File 'lib/norbelys/models/person_detail.rb', line 502

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/norbelys/models/person_detail.rb', line 345

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @score > 100
  return false if @score < 0
  return false if @source.nil?
  source_validator = EnumAttributeValidator.new('String', ["csv_import", "manual", "api", "form", "inbound", "integration"])
  return false unless source_validator.valid?(@source)
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["active", "replied", "bounced", "unsubscribed", "finished"])
  return false unless status_validator.valid?(@status)
  true
end