Class: Norbelys::PersonImportStats

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/person_import_stats.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PersonImportStats

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/norbelys/models/person_import_stats.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::PersonImportStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::PersonImportStats`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'pending')
    self.pending = attributes[:'pending']
  else
    self.pending = nil
  end

  if attributes.key?(:'processed')
    self.processed = attributes[:'processed']
  else
    self.processed = nil
  end

  if attributes.key?(:'reasons')
    if (value = attributes[:'reasons']).is_a?(Array)
      self.reasons = value
    end
  else
    self.reasons = nil
  end

  if attributes.key?(:'sendable')
    self.sendable = attributes[:'sendable']
  else
    self.sendable = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'suppressed_existing')
    self.suppressed_existing = attributes[:'suppressed_existing']
  else
    self.suppressed_existing = nil
  end

  if attributes.key?(:'suppressed_new')
    self.suppressed_new = attributes[:'suppressed_new']
  else
    self.suppressed_new = nil
  end
end

Instance Attribute Details

#createdObject

New people this import inserted.



19
20
21
# File 'lib/norbelys/models/person_import_stats.rb', line 19

def created
  @created
end

#idObject

The import id.



22
23
24
# File 'lib/norbelys/models/person_import_stats.rb', line 22

def id
  @id
end

#objectObject

Returns the value of attribute object.



24
25
26
# File 'lib/norbelys/models/person_import_stats.rb', line 24

def object
  @object
end

#pendingObject

Created people still awaiting a verdict (created − processed).



27
28
29
# File 'lib/norbelys/models/person_import_stats.rb', line 27

def pending
  @pending
end

#processedObject

How many of the created people have been verified so far.



30
31
32
# File 'lib/norbelys/models/person_import_stats.rb', line 30

def processed
  @processed
end

#reasonsObject

The cleaning report: WHAT the verification found, per reason — which addresses were removed as dead domains, likely typos, disposables, previously bounced, and so on. Ordered by count, descending.



33
34
35
# File 'lib/norbelys/models/person_import_stats.rb', line 33

def reasons
  @reasons
end

#sendableObject

Verified and safe to email.



36
37
38
# File 'lib/norbelys/models/person_import_stats.rb', line 36

def sendable
  @sendable
end

#statusObject

processing while addresses are still being verified, completed once every created person has a verdict.



39
40
41
# File 'lib/norbelys/models/person_import_stats.rb', line 39

def status
  @status
end

#suppressed_existingObject

Already on the suppression list before the import, so verification was skipped.



42
43
44
# File 'lib/norbelys/models/person_import_stats.rb', line 42

def suppressed_existing
  @suppressed_existing
end

#suppressed_newObject

Newly suppressed by an undeliverable verdict.



45
46
47
# File 'lib/norbelys/models/person_import_stats.rb', line 45

def suppressed_new
  @suppressed_new
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/norbelys/models/person_import_stats.rb', line 431

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/norbelys/models/person_import_stats.rb', line 86

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/norbelys/models/person_import_stats.rb', line 70

def self.attribute_map
  {
    :'created' => :'created',
    :'id' => :'id',
    :'object' => :'object',
    :'pending' => :'pending',
    :'processed' => :'processed',
    :'reasons' => :'reasons',
    :'sendable' => :'sendable',
    :'status' => :'status',
    :'suppressed_existing' => :'suppressedExisting',
    :'suppressed_new' => :'suppressedNew'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/norbelys/models/person_import_stats.rb', line 407

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
# File 'lib/norbelys/models/person_import_stats.rb', line 107

def self.openapi_nullable
  Set.new([
    :'object',
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/norbelys/models/person_import_stats.rb', line 91

def self.openapi_types
  {
    :'created' => :'Integer',
    :'id' => :'String',
    :'object' => :'Object',
    :'pending' => :'Integer',
    :'processed' => :'Integer',
    :'reasons' => :'Array<PersonImportReason>',
    :'sendable' => :'Integer',
    :'status' => :'String',
    :'suppressed_existing' => :'Integer',
    :'suppressed_new' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/norbelys/models/person_import_stats.rb', line 377

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      id == o.id &&
      object == o.object &&
      pending == o.pending &&
      processed == o.processed &&
      reasons == o.reasons &&
      sendable == o.sendable &&
      status == o.status &&
      suppressed_existing == o.suppressed_existing &&
      suppressed_new == o.suppressed_new
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/norbelys/models/person_import_stats.rb', line 502

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


394
395
396
# File 'lib/norbelys/models/person_import_stats.rb', line 394

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



400
401
402
# File 'lib/norbelys/models/person_import_stats.rb', line 400

def hash
  [created, id, object, pending, processed, reasons, sendable, status, suppressed_existing, suppressed_new].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/norbelys/models/person_import_stats.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @created < 0
    invalid_properties.push('invalid value for "created", must be greater than or equal to 0.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @pending.nil?
    invalid_properties.push('invalid value for "pending", pending cannot be nil.')
  end

  if @pending < 0
    invalid_properties.push('invalid value for "pending", must be greater than or equal to 0.')
  end

  if @processed.nil?
    invalid_properties.push('invalid value for "processed", processed cannot be nil.')
  end

  if @processed < 0
    invalid_properties.push('invalid value for "processed", must be greater than or equal to 0.')
  end

  if @reasons.nil?
    invalid_properties.push('invalid value for "reasons", reasons cannot be nil.')
  end

  if @sendable.nil?
    invalid_properties.push('invalid value for "sendable", sendable cannot be nil.')
  end

  if @sendable < 0
    invalid_properties.push('invalid value for "sendable", must be greater than or equal to 0.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @suppressed_existing.nil?
    invalid_properties.push('invalid value for "suppressed_existing", suppressed_existing cannot be nil.')
  end

  if @suppressed_existing < 0
    invalid_properties.push('invalid value for "suppressed_existing", must be greater than or equal to 0.')
  end

  if @suppressed_new.nil?
    invalid_properties.push('invalid value for "suppressed_new", suppressed_new cannot be nil.')
  end

  if @suppressed_new < 0
    invalid_properties.push('invalid value for "suppressed_new", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



478
479
480
# File 'lib/norbelys/models/person_import_stats.rb', line 478

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



484
485
486
487
488
489
490
491
492
493
494
495
496
# File 'lib/norbelys/models/person_import_stats.rb', line 484

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



472
473
474
# File 'lib/norbelys/models/person_import_stats.rb', line 472

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/norbelys/models/person_import_stats.rb', line 259

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created.nil?
  return false if @created < 0
  return false if @id.nil?
  return false if @pending.nil?
  return false if @pending < 0
  return false if @processed.nil?
  return false if @processed < 0
  return false if @reasons.nil?
  return false if @sendable.nil?
  return false if @sendable < 0
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["processing", "completed"])
  return false unless status_validator.valid?(@status)
  return false if @suppressed_existing.nil?
  return false if @suppressed_existing < 0
  return false if @suppressed_new.nil?
  return false if @suppressed_new < 0
  true
end