Class: Norbelys::PulseProgram

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/pulse_program.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PulseProgram

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/norbelys/models/pulse_program.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::PulseProgram` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::PulseProgram`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bounces')
    self.bounces = attributes[:'bounces']
  else
    self.bounces = nil
  end

  if attributes.key?(:'clicks')
    self.clicks = attributes[:'clicks']
  else
    self.clicks = nil
  end

  if attributes.key?(:'completion')
    self.completion = attributes[:'completion']
  else
    self.completion = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'leads')
    self.leads = attributes[:'leads']
  else
    self.leads = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'next_send_at')
    self.next_send_at = attributes[:'next_send_at']
  end

  if attributes.key?(:'open_rate')
    self.open_rate = attributes[:'open_rate']
  else
    self.open_rate = nil
  end

  if attributes.key?(:'opens')
    self.opens = attributes[:'opens']
  else
    self.opens = nil
  end

  if attributes.key?(:'replies')
    self.replies = attributes[:'replies']
  else
    self.replies = nil
  end

  if attributes.key?(:'reply_rate')
    self.reply_rate = attributes[:'reply_rate']
  else
    self.reply_rate = nil
  end

  if attributes.key?(:'sent')
    self.sent = attributes[:'sent']
  else
    self.sent = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#bouncesObject

Hard bounces in the window. Example: 3



19
20
21
# File 'lib/norbelys/models/pulse_program.rb', line 19

def bounces
  @bounces
end

#clicksObject

Clicks in the window. Example: 58



22
23
24
# File 'lib/norbelys/models/pulse_program.rb', line 22

def clicks
  @clicks
end

#completionObject

Fraction of leads in a terminal state (0-1). Example: 0.35



25
26
27
# File 'lib/norbelys/models/pulse_program.rb', line 25

def completion
  @completion
end

#idObject

The program id. Example: prg_8kd0f2n1x7q4



28
29
30
# File 'lib/norbelys/models/pulse_program.rb', line 28

def id
  @id
end

#leadsObject

Live (non-archived) enrollments. Example: 1240



31
32
33
# File 'lib/norbelys/models/pulse_program.rb', line 31

def leads
  @leads
end

#nameObject

The campaign's display name. Example: Q3 Outbound — Founders



34
35
36
# File 'lib/norbelys/models/pulse_program.rb', line 34

def name
  @name
end

#next_send_atObject

Returns the value of attribute next_send_at.



36
37
38
# File 'lib/norbelys/models/pulse_program.rb', line 36

def next_send_at
  @next_send_at
end

#open_rateObject

Opens ÷ delivered in the window (0-1). Example: 0.42



39
40
41
# File 'lib/norbelys/models/pulse_program.rb', line 39

def open_rate
  @open_rate
end

#opensObject

Opens in the window. Example: 312



42
43
44
# File 'lib/norbelys/models/pulse_program.rb', line 42

def opens
  @opens
end

#repliesObject

Replies in the window. Example: 24



45
46
47
# File 'lib/norbelys/models/pulse_program.rb', line 45

def replies
  @replies
end

#reply_rateObject

Replies ÷ delivered in the window (0-1). Example: 0.08



48
49
50
# File 'lib/norbelys/models/pulse_program.rb', line 48

def reply_rate
  @reply_rate
end

#sentObject

Messages sent in the window. Example: 740



51
52
53
# File 'lib/norbelys/models/pulse_program.rb', line 51

def sent
  @sent
end

#statusObject

Campaign status: draft, active, paused, or done. Example: active



54
55
56
# File 'lib/norbelys/models/pulse_program.rb', line 54

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/norbelys/models/pulse_program.rb', line 366

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/norbelys/models/pulse_program.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/norbelys/models/pulse_program.rb', line 79

def self.attribute_map
  {
    :'bounces' => :'bounces',
    :'clicks' => :'clicks',
    :'completion' => :'completion',
    :'id' => :'id',
    :'leads' => :'leads',
    :'name' => :'name',
    :'next_send_at' => :'nextSendAt',
    :'open_rate' => :'openRate',
    :'opens' => :'opens',
    :'replies' => :'replies',
    :'reply_rate' => :'replyRate',
    :'sent' => :'sent',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/norbelys/models/pulse_program.rb', line 342

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
126
# File 'lib/norbelys/models/pulse_program.rb', line 122

def self.openapi_nullable
  Set.new([
    :'next_send_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/norbelys/models/pulse_program.rb', line 103

def self.openapi_types
  {
    :'bounces' => :'Float',
    :'clicks' => :'Float',
    :'completion' => :'Float',
    :'id' => :'String',
    :'leads' => :'Float',
    :'name' => :'String',
    :'next_send_at' => :'Object',
    :'open_rate' => :'Float',
    :'opens' => :'Float',
    :'replies' => :'Float',
    :'reply_rate' => :'Float',
    :'sent' => :'Float',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/norbelys/models/pulse_program.rb', line 309

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bounces == o.bounces &&
      clicks == o.clicks &&
      completion == o.completion &&
      id == o.id &&
      leads == o.leads &&
      name == o.name &&
      next_send_at == o.next_send_at &&
      open_rate == o.open_rate &&
      opens == o.opens &&
      replies == o.replies &&
      reply_rate == o.reply_rate &&
      sent == o.sent &&
      status == o.status
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/norbelys/models/pulse_program.rb', line 437

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


329
330
331
# File 'lib/norbelys/models/pulse_program.rb', line 329

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



335
336
337
# File 'lib/norbelys/models/pulse_program.rb', line 335

def hash
  [bounces, clicks, completion, id, leads, name, next_send_at, open_rate, opens, replies, reply_rate, sent, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/norbelys/models/pulse_program.rb', line 222

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @bounces.nil?
    invalid_properties.push('invalid value for "bounces", bounces cannot be nil.')
  end

  if @clicks.nil?
    invalid_properties.push('invalid value for "clicks", clicks cannot be nil.')
  end

  if @completion.nil?
    invalid_properties.push('invalid value for "completion", completion cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @leads.nil?
    invalid_properties.push('invalid value for "leads", leads cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @open_rate.nil?
    invalid_properties.push('invalid value for "open_rate", open_rate cannot be nil.')
  end

  if @opens.nil?
    invalid_properties.push('invalid value for "opens", opens cannot be nil.')
  end

  if @replies.nil?
    invalid_properties.push('invalid value for "replies", replies cannot be nil.')
  end

  if @reply_rate.nil?
    invalid_properties.push('invalid value for "reply_rate", reply_rate cannot be nil.')
  end

  if @sent.nil?
    invalid_properties.push('invalid value for "sent", sent cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



413
414
415
# File 'lib/norbelys/models/pulse_program.rb', line 413

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/norbelys/models/pulse_program.rb', line 419

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



407
408
409
# File 'lib/norbelys/models/pulse_program.rb', line 407

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/norbelys/models/pulse_program.rb', line 278

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @bounces.nil?
  return false if @clicks.nil?
  return false if @completion.nil?
  return false if @id.nil?
  return false if @leads.nil?
  return false if @name.nil?
  return false if @open_rate.nil?
  return false if @opens.nil?
  return false if @replies.nil?
  return false if @reply_rate.nil?
  return false if @sent.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["draft", "active", "paused", "done"])
  return false unless status_validator.valid?(@status)
  true
end