Class: Norbelys::SegmentsApi
- Inherits:
-
Object
- Object
- Norbelys::SegmentsApi
- Defined in:
- lib/norbelys/api/segments_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SegmentsApi
constructor
A new instance of SegmentsApi.
-
#segments_archive(id, opts = {}) ⇒ Segment
Delete a segment Permanently delete the segment and detach it from any program that used it as an audience source.
-
#segments_archive_with_http_info(id, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Delete a segment Permanently delete the segment and detach it from any program that used it as an audience source.
-
#segments_create(segment_create_params, opts = {}) ⇒ Segment
Create a segment Create a segment: a named, saved audience filter (the rule tree in
definition). -
#segments_create_with_http_info(segment_create_params, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Create a segment Create a segment: a named, saved audience filter (the rule tree in `definition`).
-
#segments_find(id, opts = {}) ⇒ Segment
Get a segment Read one segment, including its saved filter definition.
-
#segments_find_with_http_info(id, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Get a segment Read one segment, including its saved filter definition.
-
#segments_list(opts = {}) ⇒ SegmentList
List segments List the org's segments — dynamic saved filters over people — newest first.
-
#segments_list_with_http_info(opts = {}) ⇒ Array<(SegmentList, Integer, Hash)>
List segments List the org's segments — dynamic saved filters over people — newest first.
-
#segments_update(id, opts = {}) ⇒ Segment
Update a segment Rename a segment or replace its filter definition.
-
#segments_update_with_http_info(id, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Update a segment Rename a segment or replace its filter definition.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SegmentsApi
Returns a new instance of SegmentsApi.
19 20 21 |
# File 'lib/norbelys/api/segments_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/norbelys/api/segments_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#segments_archive(id, opts = {}) ⇒ Segment
Delete a segment Permanently delete the segment and detach it from any program that used it as an audience source. The people it matched are unaffected.
27 28 29 30 |
# File 'lib/norbelys/api/segments_api.rb', line 27 def segments_archive(id, opts = {}) data, _status_code, _headers = segments_archive_with_http_info(id, opts) data end |
#segments_archive_with_http_info(id, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Delete a segment Permanently delete the segment and detach it from any program that used it as an audience source. The people it matched are unaffected.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/norbelys/api/segments_api.rb', line 37 def segments_archive_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.segments_archive ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SegmentsApi.segments_archive" end # resource path local_var_path = '/segments/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Segment' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SegmentsApi.segments_archive", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#segments_archive\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#segments_create(segment_create_params, opts = {}) ⇒ Segment
Create a segment
Create a segment: a named, saved audience filter (the rule tree in definition). Membership is computed live, so it auto-refreshes as people change. Preview the people it matches at GET /v1/people?segmentId=id.
91 92 93 94 |
# File 'lib/norbelys/api/segments_api.rb', line 91 def segments_create(segment_create_params, opts = {}) data, _status_code, _headers = segments_create_with_http_info(segment_create_params, opts) data end |
#segments_create_with_http_info(segment_create_params, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Create a segment Create a segment: a named, saved audience filter (the rule tree in `definition`). Membership is computed live, so it auto-refreshes as people change. Preview the people it matches at GET /v1/people?segmentId=id.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/norbelys/api/segments_api.rb', line 102 def segments_create_with_http_info(segment_create_params, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.segments_create ...' end # verify the required parameter 'segment_create_params' is set if @api_client.config.client_side_validation && segment_create_params.nil? fail ArgumentError, "Missing the required parameter 'segment_create_params' when calling SegmentsApi.segments_create" end if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling SegmentsApi.segments_create, the character length must be smaller than or equal to 255.' end # resource path local_var_path = '/segments' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(segment_create_params) # return_type return_type = opts[:debug_return_type] || 'Segment' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SegmentsApi.segments_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#segments_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#segments_find(id, opts = {}) ⇒ Segment
Get a segment Read one segment, including its saved filter definition. List the people it currently matches at GET /v1/people?segmentId=id.
165 166 167 168 |
# File 'lib/norbelys/api/segments_api.rb', line 165 def segments_find(id, opts = {}) data, _status_code, _headers = segments_find_with_http_info(id, opts) data end |
#segments_find_with_http_info(id, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Get a segment Read one segment, including its saved filter definition. List the people it currently matches at GET /v1/people?segmentId=id.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/norbelys/api/segments_api.rb', line 175 def segments_find_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.segments_find ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SegmentsApi.segments_find" end # resource path local_var_path = '/segments/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Segment' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SegmentsApi.segments_find", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#segments_find\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#segments_list(opts = {}) ⇒ SegmentList
List segments List the org's segments — dynamic saved filters over people — newest first.
231 232 233 234 |
# File 'lib/norbelys/api/segments_api.rb', line 231 def segments_list(opts = {}) data, _status_code, _headers = segments_list_with_http_info(opts) data end |
#segments_list_with_http_info(opts = {}) ⇒ Array<(SegmentList, Integer, Hash)>
List segments List the org's segments — dynamic saved filters over people — newest first.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/norbelys/api/segments_api.rb', line 244 def segments_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.segments_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SegmentsApi.segments_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SegmentsApi.segments_list, must be greater than or equal to 1.' end # resource path local_var_path = '/segments' # query parameters query_params = opts[:query_params] || {} query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'includeArchived'] = opts[:'include_archived'] if !opts[:'include_archived'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SegmentList' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SegmentsApi.segments_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#segments_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#segments_update(id, opts = {}) ⇒ Segment
Update a segment Rename a segment or replace its filter definition. Because membership is computed live, changing the definition immediately changes who the segment matches.
306 307 308 309 |
# File 'lib/norbelys/api/segments_api.rb', line 306 def segments_update(id, opts = {}) data, _status_code, _headers = segments_update_with_http_info(id, opts) data end |
#segments_update_with_http_info(id, opts = {}) ⇒ Array<(Segment, Integer, Hash)>
Update a segment Rename a segment or replace its filter definition. Because membership is computed live, changing the definition immediately changes who the segment matches.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/norbelys/api/segments_api.rb', line 317 def segments_update_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SegmentsApi.segments_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SegmentsApi.segments_update" end # resource path local_var_path = '/segments/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'segment_update_params']) # return_type return_type = opts[:debug_return_type] || 'Segment' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SegmentsApi.segments_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SegmentsApi#segments_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |