Class: Norbelys::SmtpSenderInput

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/smtp_sender_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SmtpSenderInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/norbelys/models/smtp_sender_input.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::SmtpSenderInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::SmtpSenderInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bcc_crm_email')
    self.bcc_crm_email = attributes[:'bcc_crm_email']
  end

  if attributes.key?(:'client_label')
    self.client_label = attributes[:'client_label']
  end

  if attributes.key?(:'daily_limit')
    self.daily_limit = attributes[:'daily_limit']
  end

  if attributes.key?(:'min_gap_minutes')
    self.min_gap_minutes = attributes[:'min_gap_minutes']
  end

  if attributes.key?(:'reply_to')
    self.reply_to = attributes[:'reply_to']
  end

  if attributes.key?(:'sending_domain_id')
    self.sending_domain_id = attributes[:'sending_domain_id']
  end

  if attributes.key?(:'signature_html')
    self.signature_html = attributes[:'signature_html']
  end

  if attributes.key?(:'from_email')
    self.from_email = attributes[:'from_email']
  else
    self.from_email = nil
  end

  if attributes.key?(:'from_name')
    self.from_name = attributes[:'from_name']
  else
    self.from_name = nil
  end

  if attributes.key?(:'imap')
    self.imap = attributes[:'imap']
  end

  if attributes.key?(:'smtp')
    self.smtp = attributes[:'smtp']
  else
    self.smtp = nil
  end

  if attributes.key?(:'transport_mode')
    self.transport_mode = attributes[:'transport_mode']
  else
    self.transport_mode = nil
  end
end

Instance Attribute Details

#bcc_crm_emailObject

BCC every send to this address (CRM capture).



19
20
21
# File 'lib/norbelys/models/smtp_sender_input.rb', line 19

def bcc_crm_email
  @bcc_crm_email
end

#client_labelObject

Free-text label for this mailbox (e.g. to tag by client).



22
23
24
# File 'lib/norbelys/models/smtp_sender_input.rb', line 22

def client_label
  @client_label
end

#daily_limitObject

Maximum sends per day for this mailbox.



25
26
27
# File 'lib/norbelys/models/smtp_sender_input.rb', line 25

def daily_limit
  @daily_limit
end

#from_emailObject

The sending address.



40
41
42
# File 'lib/norbelys/models/smtp_sender_input.rb', line 40

def from_email
  @from_email
end

#from_nameObject

Display name.



43
44
45
# File 'lib/norbelys/models/smtp_sender_input.rb', line 43

def from_name
  @from_name
end

#imapObject

Returns the value of attribute imap.



45
46
47
# File 'lib/norbelys/models/smtp_sender_input.rb', line 45

def imap
  @imap
end

#min_gap_minutesObject

Minimum gap between sends from this mailbox (floor 3; server default 5).



28
29
30
# File 'lib/norbelys/models/smtp_sender_input.rb', line 28

def min_gap_minutes
  @min_gap_minutes
end

#reply_toObject

Reply-To override.



31
32
33
# File 'lib/norbelys/models/smtp_sender_input.rb', line 31

def reply_to
  @reply_to
end

#sending_domain_idObject

The sending domain id. Omit to get-or-create it from the fromEmail host.



34
35
36
# File 'lib/norbelys/models/smtp_sender_input.rb', line 34

def sending_domain_id
  @sending_domain_id
end

#signature_htmlObject

HTML signature appended to every send.



37
38
39
# File 'lib/norbelys/models/smtp_sender_input.rb', line 37

def signature_html
  @signature_html
end

#smtpObject

Returns the value of attribute smtp.



47
48
49
# File 'lib/norbelys/models/smtp_sender_input.rb', line 47

def smtp
  @smtp
end

#transport_modeObject

Returns the value of attribute transport_mode.



49
50
51
# File 'lib/norbelys/models/smtp_sender_input.rb', line 49

def transport_mode
  @transport_mode
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/norbelys/models/smtp_sender_input.rb', line 316

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/norbelys/models/smtp_sender_input.rb', line 70

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/norbelys/models/smtp_sender_input.rb', line 52

def self.attribute_map
  {
    :'bcc_crm_email' => :'bccCrmEmail',
    :'client_label' => :'clientLabel',
    :'daily_limit' => :'dailyLimit',
    :'min_gap_minutes' => :'minGapMinutes',
    :'reply_to' => :'replyTo',
    :'sending_domain_id' => :'sendingDomainId',
    :'signature_html' => :'signatureHtml',
    :'from_email' => :'fromEmail',
    :'from_name' => :'fromName',
    :'imap' => :'imap',
    :'smtp' => :'smtp',
    :'transport_mode' => :'transportMode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/norbelys/models/smtp_sender_input.rb', line 292

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
# File 'lib/norbelys/models/smtp_sender_input.rb', line 93

def self.openapi_nullable
  Set.new([
    :'transport_mode'
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/norbelys/models/smtp_sender_input.rb', line 75

def self.openapi_types
  {
    :'bcc_crm_email' => :'String',
    :'client_label' => :'String',
    :'daily_limit' => :'Integer',
    :'min_gap_minutes' => :'Integer',
    :'reply_to' => :'String',
    :'sending_domain_id' => :'String',
    :'signature_html' => :'String',
    :'from_email' => :'String',
    :'from_name' => :'String',
    :'imap' => :'ConnectionSettings',
    :'smtp' => :'SmtpConnectionSettings',
    :'transport_mode' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/norbelys/models/smtp_sender_input.rb', line 260

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bcc_crm_email == o.bcc_crm_email &&
      client_label == o.client_label &&
      daily_limit == o.daily_limit &&
      min_gap_minutes == o.min_gap_minutes &&
      reply_to == o.reply_to &&
      sending_domain_id == o.sending_domain_id &&
      signature_html == o.signature_html &&
      from_email == o.from_email &&
      from_name == o.from_name &&
      imap == o.imap &&
      smtp == o.smtp &&
      transport_mode == o.transport_mode
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/norbelys/models/smtp_sender_input.rb', line 387

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


279
280
281
# File 'lib/norbelys/models/smtp_sender_input.rb', line 279

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



285
286
287
# File 'lib/norbelys/models/smtp_sender_input.rb', line 285

def hash
  [bcc_crm_email, client_label, daily_limit, min_gap_minutes, reply_to, sending_domain_id, signature_html, from_email, from_name, imap, smtp, transport_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/norbelys/models/smtp_sender_input.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@daily_limit.nil? && @daily_limit < 0
    invalid_properties.push('invalid value for "daily_limit", must be greater than or equal to 0.')
  end

  if !@min_gap_minutes.nil? && @min_gap_minutes < 3
    invalid_properties.push('invalid value for "min_gap_minutes", must be greater than or equal to 3.')
  end

  if @from_email.nil?
    invalid_properties.push('invalid value for "from_email", from_email cannot be nil.')
  end

  if @from_email.to_s.length < 1
    invalid_properties.push('invalid value for "from_email", the character length must be great than or equal to 1.')
  end

  if @from_name.nil?
    invalid_properties.push('invalid value for "from_name", from_name cannot be nil.')
  end

  if @smtp.nil?
    invalid_properties.push('invalid value for "smtp", smtp cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
# File 'lib/norbelys/models/smtp_sender_input.rb', line 363

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/norbelys/models/smtp_sender_input.rb', line 369

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



357
358
359
# File 'lib/norbelys/models/smtp_sender_input.rb', line 357

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
212
213
214
# File 'lib/norbelys/models/smtp_sender_input.rb', line 205

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@daily_limit.nil? && @daily_limit < 0
  return false if !@min_gap_minutes.nil? && @min_gap_minutes < 3
  return false if @from_email.nil?
  return false if @from_email.to_s.length < 1
  return false if @from_name.nil?
  return false if @smtp.nil?
  true
end