Class: Norbelys::StepWithVariants

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/step_with_variants.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StepWithVariants

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/norbelys/models/step_with_variants.rb', line 140

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::StepWithVariants` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::StepWithVariants`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ab_min_sample')
    self.ab_min_sample = attributes[:'ab_min_sample']
  else
    self.ab_min_sample = nil
  end

  if attributes.key?(:'ab_mode')
    self.ab_mode = attributes[:'ab_mode']
  else
    self.ab_mode = nil
  end

  if attributes.key?(:'ab_test_pct')
    self.ab_test_pct = attributes[:'ab_test_pct']
  else
    self.ab_test_pct = nil
  end

  if attributes.key?(:'ab_winner_variant_id')
    self.ab_winner_variant_id = attributes[:'ab_winner_variant_id']
  else
    self.ab_winner_variant_id = nil
  end

  if attributes.key?(:'ab_winning_metric')
    self.ab_winning_metric = attributes[:'ab_winning_metric']
  else
    self.ab_winning_metric = nil
  end

  if attributes.key?(:'archived_at')
    self.archived_at = attributes[:'archived_at']
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  else
    self.channel = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'order_idx')
    self.order_idx = attributes[:'order_idx']
  else
    self.order_idx = nil
  end

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  else
    self.program_id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'wait_days')
    self.wait_days = attributes[:'wait_days']
  else
    self.wait_days = nil
  end

  if attributes.key?(:'variants')
    if (value = attributes[:'variants']).is_a?(Array)
      self.variants = value
    end
  else
    self.variants = nil
  end
end

Instance Attribute Details

#ab_min_sampleObject

Minimum sends before a winner can be decided.



19
20
21
# File 'lib/norbelys/models/step_with_variants.rb', line 19

def ab_min_sample
  @ab_min_sample
end

#ab_modeObject

How the A/B winner is decided: manual, even, ai_percentage.



22
23
24
# File 'lib/norbelys/models/step_with_variants.rb', line 22

def ab_mode
  @ab_mode
end

#ab_test_pctObject

Percent of leads in the test group while the test holds.



25
26
27
# File 'lib/norbelys/models/step_with_variants.rb', line 25

def ab_test_pct
  @ab_test_pct
end

#ab_winner_variant_idObject

Returns the value of attribute ab_winner_variant_id.



27
28
29
# File 'lib/norbelys/models/step_with_variants.rb', line 27

def ab_winner_variant_id
  @ab_winner_variant_id
end

#ab_winning_metricObject

Metric the winner is decided by: reply, positive_reply, click, open.



30
31
32
# File 'lib/norbelys/models/step_with_variants.rb', line 30

def ab_winning_metric
  @ab_winning_metric
end

#archived_atObject

Returns the value of attribute archived_at.



32
33
34
# File 'lib/norbelys/models/step_with_variants.rb', line 32

def archived_at
  @archived_at
end

#channelObject

Send channel: email, call, sms, linkedin.



35
36
37
# File 'lib/norbelys/models/step_with_variants.rb', line 35

def channel
  @channel
end

#created_atObject

Returns the value of attribute created_at.



37
38
39
# File 'lib/norbelys/models/step_with_variants.rb', line 37

def created_at
  @created_at
end

#idObject

The step id.



40
41
42
# File 'lib/norbelys/models/step_with_variants.rb', line 40

def id
  @id
end

#objectObject

Returns the value of attribute object.



42
43
44
# File 'lib/norbelys/models/step_with_variants.rb', line 42

def object
  @object
end

#order_idxObject

Position in the cadence, 0-based.



45
46
47
# File 'lib/norbelys/models/step_with_variants.rb', line 45

def order_idx
  @order_idx
end

#program_idObject

The owning program's id.



48
49
50
# File 'lib/norbelys/models/step_with_variants.rb', line 48

def program_id
  @program_id
end

#typeObject

Step type: email, wait, condition, call.



51
52
53
# File 'lib/norbelys/models/step_with_variants.rb', line 51

def type
  @type
end

#variantsObject

The step's live (un-archived) arms, in creation order.



57
58
59
# File 'lib/norbelys/models/step_with_variants.rb', line 57

def variants
  @variants
end

#wait_daysObject

Days to wait after the previous step before this one sends.



54
55
56
# File 'lib/norbelys/models/step_with_variants.rb', line 54

def wait_days
  @wait_days
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/norbelys/models/step_with_variants.rb', line 504

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/norbelys/models/step_with_variants.rb', line 103

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/norbelys/models/step_with_variants.rb', line 82

def self.attribute_map
  {
    :'ab_min_sample' => :'abMinSample',
    :'ab_mode' => :'abMode',
    :'ab_test_pct' => :'abTestPct',
    :'ab_winner_variant_id' => :'abWinnerVariantId',
    :'ab_winning_metric' => :'abWinningMetric',
    :'archived_at' => :'archivedAt',
    :'channel' => :'channel',
    :'created_at' => :'createdAt',
    :'id' => :'id',
    :'object' => :'object',
    :'order_idx' => :'orderIdx',
    :'program_id' => :'programId',
    :'type' => :'type',
    :'wait_days' => :'waitDays',
    :'variants' => :'variants'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/norbelys/models/step_with_variants.rb', line 480

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



129
130
131
132
133
134
135
136
# File 'lib/norbelys/models/step_with_variants.rb', line 129

def self.openapi_nullable
  Set.new([
    :'ab_winner_variant_id',
    :'archived_at',
    :'created_at',
    :'object',
  ])
end

.openapi_typesObject

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/norbelys/models/step_with_variants.rb', line 108

def self.openapi_types
  {
    :'ab_min_sample' => :'Integer',
    :'ab_mode' => :'String',
    :'ab_test_pct' => :'Integer',
    :'ab_winner_variant_id' => :'String',
    :'ab_winning_metric' => :'String',
    :'archived_at' => :'Object',
    :'channel' => :'String',
    :'created_at' => :'Object',
    :'id' => :'String',
    :'object' => :'Object',
    :'order_idx' => :'Integer',
    :'program_id' => :'String',
    :'type' => :'String',
    :'wait_days' => :'Integer',
    :'variants' => :'Array<Variant>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/norbelys/models/step_with_variants.rb', line 445

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ab_min_sample == o.ab_min_sample &&
      ab_mode == o.ab_mode &&
      ab_test_pct == o.ab_test_pct &&
      ab_winner_variant_id == o.ab_winner_variant_id &&
      ab_winning_metric == o.ab_winning_metric &&
      archived_at == o.archived_at &&
      channel == o.channel &&
      created_at == o.created_at &&
      id == o.id &&
      object == o.object &&
      order_idx == o.order_idx &&
      program_id == o.program_id &&
      type == o.type &&
      wait_days == o.wait_days &&
      variants == o.variants
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/norbelys/models/step_with_variants.rb', line 575

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


467
468
469
# File 'lib/norbelys/models/step_with_variants.rb', line 467

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



473
474
475
# File 'lib/norbelys/models/step_with_variants.rb', line 473

def hash
  [ab_min_sample, ab_mode, ab_test_pct, ab_winner_variant_id, ab_winning_metric, archived_at, channel, created_at, id, object, order_idx, program_id, type, wait_days, variants].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/norbelys/models/step_with_variants.rb', line 242

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ab_min_sample.nil?
    invalid_properties.push('invalid value for "ab_min_sample", ab_min_sample cannot be nil.')
  end

  if @ab_min_sample < 1
    invalid_properties.push('invalid value for "ab_min_sample", must be greater than or equal to 1.')
  end

  if @ab_mode.nil?
    invalid_properties.push('invalid value for "ab_mode", ab_mode cannot be nil.')
  end

  if @ab_test_pct.nil?
    invalid_properties.push('invalid value for "ab_test_pct", ab_test_pct cannot be nil.')
  end

  if @ab_test_pct > 100
    invalid_properties.push('invalid value for "ab_test_pct", must be smaller than or equal to 100.')
  end

  if @ab_test_pct < 0
    invalid_properties.push('invalid value for "ab_test_pct", must be greater than or equal to 0.')
  end

  if @ab_winning_metric.nil?
    invalid_properties.push('invalid value for "ab_winning_metric", ab_winning_metric cannot be nil.')
  end

  if @channel.nil?
    invalid_properties.push('invalid value for "channel", channel cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @order_idx.nil?
    invalid_properties.push('invalid value for "order_idx", order_idx cannot be nil.')
  end

  if @order_idx < 0
    invalid_properties.push('invalid value for "order_idx", must be greater than or equal to 0.')
  end

  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @wait_days.nil?
    invalid_properties.push('invalid value for "wait_days", wait_days cannot be nil.')
  end

  if @wait_days < 0
    invalid_properties.push('invalid value for "wait_days", must be greater than or equal to 0.')
  end

  if @variants.nil?
    invalid_properties.push('invalid value for "variants", variants cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



551
552
553
# File 'lib/norbelys/models/step_with_variants.rb', line 551

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/norbelys/models/step_with_variants.rb', line 557

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



545
546
547
# File 'lib/norbelys/models/step_with_variants.rb', line 545

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/norbelys/models/step_with_variants.rb', line 314

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ab_min_sample.nil?
  return false if @ab_min_sample < 1
  return false if @ab_mode.nil?
  ab_mode_validator = EnumAttributeValidator.new('String', ["manual", "even", "ai_percentage"])
  return false unless ab_mode_validator.valid?(@ab_mode)
  return false if @ab_test_pct.nil?
  return false if @ab_test_pct > 100
  return false if @ab_test_pct < 0
  return false if @ab_winning_metric.nil?
  ab_winning_metric_validator = EnumAttributeValidator.new('String', ["reply", "positive_reply", "click", "open"])
  return false unless ab_winning_metric_validator.valid?(@ab_winning_metric)
  return false if @channel.nil?
  channel_validator = EnumAttributeValidator.new('String', ["email", "call", "sms", "linkedin"])
  return false unless channel_validator.valid?(@channel)
  return false if @id.nil?
  return false if @order_idx.nil?
  return false if @order_idx < 0
  return false if @program_id.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["email", "wait", "condition", "call"])
  return false unless type_validator.valid?(@type)
  return false if @wait_days.nil?
  return false if @wait_days < 0
  return false if @variants.nil?
  true
end