Class: Norbelys::UpdateSenderInput

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/update_sender_input.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSenderInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/norbelys/models/update_sender_input.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::UpdateSenderInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::UpdateSenderInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bcc_crm_email')
    self.bcc_crm_email = attributes[:'bcc_crm_email']
  end

  if attributes.key?(:'client_label')
    self.client_label = attributes[:'client_label']
  end

  if attributes.key?(:'daily_limit')
    self.daily_limit = attributes[:'daily_limit']
  end

  if attributes.key?(:'min_gap_minutes')
    self.min_gap_minutes = attributes[:'min_gap_minutes']
  end

  if attributes.key?(:'reply_to')
    self.reply_to = attributes[:'reply_to']
  end

  if attributes.key?(:'sending_domain_id')
    self.sending_domain_id = attributes[:'sending_domain_id']
  end

  if attributes.key?(:'signature_html')
    self.signature_html = attributes[:'signature_html']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'warmup')
    self.warmup = attributes[:'warmup']
  end

  if attributes.key?(:'archived_at')
    self.archived_at = attributes[:'archived_at']
  end

  if attributes.key?(:'from_email')
    self.from_email = attributes[:'from_email']
  end

  if attributes.key?(:'from_name')
    self.from_name = attributes[:'from_name']
  end

  if attributes.key?(:'imap')
    self.imap = attributes[:'imap']
  end

  if attributes.key?(:'smtp')
    self.smtp = attributes[:'smtp']
  end

  if attributes.key?(:'transport_mode')
    self.transport_mode = attributes[:'transport_mode']
  end

  if attributes.key?(:'transport_provider')
    self.transport_provider = attributes[:'transport_provider']
  end
end

Instance Attribute Details

#archived_atObject

Returns the value of attribute archived_at.



44
45
46
# File 'lib/norbelys/models/update_sender_input.rb', line 44

def archived_at
  @archived_at
end

#bcc_crm_emailObject

BCC every send to this address (CRM capture).



19
20
21
# File 'lib/norbelys/models/update_sender_input.rb', line 19

def bcc_crm_email
  @bcc_crm_email
end

#client_labelObject

Free-text label for this mailbox (e.g. to tag by client).



22
23
24
# File 'lib/norbelys/models/update_sender_input.rb', line 22

def client_label
  @client_label
end

#daily_limitObject

Maximum sends per day for this mailbox.



25
26
27
# File 'lib/norbelys/models/update_sender_input.rb', line 25

def daily_limit
  @daily_limit
end

#from_emailObject

The sending address (re-verifies the mailbox when changed).



47
48
49
# File 'lib/norbelys/models/update_sender_input.rb', line 47

def from_email
  @from_email
end

#from_nameObject

Display name.



50
51
52
# File 'lib/norbelys/models/update_sender_input.rb', line 50

def from_name
  @from_name
end

#imapObject

Returns the value of attribute imap.



52
53
54
# File 'lib/norbelys/models/update_sender_input.rb', line 52

def imap
  @imap
end

#min_gap_minutesObject

Minimum gap between sends from this mailbox (floor 3; server default 5).



28
29
30
# File 'lib/norbelys/models/update_sender_input.rb', line 28

def min_gap_minutes
  @min_gap_minutes
end

#reply_toObject

Reply-To override.



31
32
33
# File 'lib/norbelys/models/update_sender_input.rb', line 31

def reply_to
  @reply_to
end

#sending_domain_idObject

The sending domain id. Omit to get-or-create it from the fromEmail host.



34
35
36
# File 'lib/norbelys/models/update_sender_input.rb', line 34

def sending_domain_id
  @sending_domain_id
end

#signature_htmlObject

HTML signature appended to every send.



37
38
39
# File 'lib/norbelys/models/update_sender_input.rb', line 37

def signature_html
  @signature_html
end

#smtpObject

Returns the value of attribute smtp.



54
55
56
# File 'lib/norbelys/models/update_sender_input.rb', line 54

def smtp
  @smtp
end

#stateObject

Operator-set state to pause or resume the mailbox: healthy, throttled, or paused.



40
41
42
# File 'lib/norbelys/models/update_sender_input.rb', line 40

def state
  @state
end

#transport_modeObject

How messages are carried: smtp, provider_api, self_hosted, or voice.



57
58
59
# File 'lib/norbelys/models/update_sender_input.rb', line 57

def transport_mode
  @transport_mode
end

#transport_providerObject

Managed provider; omit for a plain cold/SMTP mailbox.



60
61
62
# File 'lib/norbelys/models/update_sender_input.rb', line 60

def transport_provider
  @transport_provider
end

#warmupObject

Returns the value of attribute warmup.



42
43
44
# File 'lib/norbelys/models/update_sender_input.rb', line 42

def warmup
  @warmup
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/norbelys/models/update_sender_input.rb', line 394

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/norbelys/models/update_sender_input.rb', line 107

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/norbelys/models/update_sender_input.rb', line 85

def self.attribute_map
  {
    :'bcc_crm_email' => :'bccCrmEmail',
    :'client_label' => :'clientLabel',
    :'daily_limit' => :'dailyLimit',
    :'min_gap_minutes' => :'minGapMinutes',
    :'reply_to' => :'replyTo',
    :'sending_domain_id' => :'sendingDomainId',
    :'signature_html' => :'signatureHtml',
    :'state' => :'state',
    :'warmup' => :'warmup',
    :'archived_at' => :'archivedAt',
    :'from_email' => :'fromEmail',
    :'from_name' => :'fromName',
    :'imap' => :'imap',
    :'smtp' => :'smtp',
    :'transport_mode' => :'transportMode',
    :'transport_provider' => :'transportProvider'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/norbelys/models/update_sender_input.rb', line 370

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



134
135
136
137
138
139
# File 'lib/norbelys/models/update_sender_input.rb', line 134

def self.openapi_nullable
  Set.new([
    :'warmup',
    :'archived_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/norbelys/models/update_sender_input.rb', line 112

def self.openapi_types
  {
    :'bcc_crm_email' => :'String',
    :'client_label' => :'String',
    :'daily_limit' => :'Integer',
    :'min_gap_minutes' => :'Integer',
    :'reply_to' => :'String',
    :'sending_domain_id' => :'String',
    :'signature_html' => :'String',
    :'state' => :'String',
    :'warmup' => :'WarmupSettings',
    :'archived_at' => :'Integer',
    :'from_email' => :'String',
    :'from_name' => :'String',
    :'imap' => :'ImapConnectionUpdate',
    :'smtp' => :'SmtpConnectionUpdate',
    :'transport_mode' => :'String',
    :'transport_provider' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/norbelys/models/update_sender_input.rb', line 334

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bcc_crm_email == o.bcc_crm_email &&
      client_label == o.client_label &&
      daily_limit == o.daily_limit &&
      min_gap_minutes == o.min_gap_minutes &&
      reply_to == o.reply_to &&
      sending_domain_id == o.sending_domain_id &&
      signature_html == o.signature_html &&
      state == o.state &&
      warmup == o.warmup &&
      archived_at == o.archived_at &&
      from_email == o.from_email &&
      from_name == o.from_name &&
      imap == o.imap &&
      smtp == o.smtp &&
      transport_mode == o.transport_mode &&
      transport_provider == o.transport_provider
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/norbelys/models/update_sender_input.rb', line 465

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


357
358
359
# File 'lib/norbelys/models/update_sender_input.rb', line 357

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



363
364
365
# File 'lib/norbelys/models/update_sender_input.rb', line 363

def hash
  [bcc_crm_email, client_label, daily_limit, min_gap_minutes, reply_to, sending_domain_id, signature_html, state, warmup, archived_at, from_email, from_name, imap, smtp, transport_mode, transport_provider].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/norbelys/models/update_sender_input.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@daily_limit.nil? && @daily_limit < 0
    invalid_properties.push('invalid value for "daily_limit", must be greater than or equal to 0.')
  end

  if !@min_gap_minutes.nil? && @min_gap_minutes < 3
    invalid_properties.push('invalid value for "min_gap_minutes", must be greater than or equal to 3.')
  end

  if !@archived_at.nil? && @archived_at < 0
    invalid_properties.push('invalid value for "archived_at", must be greater than or equal to 0.')
  end

  if !@from_email.nil? && @from_email.to_s.length < 1
    invalid_properties.push('invalid value for "from_email", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
# File 'lib/norbelys/models/update_sender_input.rb', line 441

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/norbelys/models/update_sender_input.rb', line 447

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



435
436
437
# File 'lib/norbelys/models/update_sender_input.rb', line 435

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/norbelys/models/update_sender_input.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@daily_limit.nil? && @daily_limit < 0
  return false if !@min_gap_minutes.nil? && @min_gap_minutes < 3
  state_validator = EnumAttributeValidator.new('String', ["healthy", "throttled", "paused"])
  return false unless state_validator.valid?(@state)
  return false if !@archived_at.nil? && @archived_at < 0
  return false if !@from_email.nil? && @from_email.to_s.length < 1
  transport_mode_validator = EnumAttributeValidator.new('String', ["smtp", "provider_api", "self_hosted", "voice"])
  return false unless transport_mode_validator.valid?(@transport_mode)
  true
end