Class: Norbelys::VoiceSenderInput
- Inherits:
-
Object
- Object
- Norbelys::VoiceSenderInput
- Defined in:
- lib/norbelys/models/voice_sender_input.rb
Instance Attribute Summary collapse
-
#bcc_crm_email ⇒ Object
BCC every send to this address (CRM capture).
-
#client_label ⇒ Object
Free-text label for this mailbox (e.g. to tag by client).
-
#daily_limit ⇒ Object
Maximum sends per day for this mailbox.
-
#from_email ⇒ Object
The sending address.
-
#from_name ⇒ Object
Display name.
-
#min_gap_minutes ⇒ Object
Minimum gap between sends from this mailbox (floor 3; server default 5).
-
#reply_to ⇒ Object
Reply-To override.
-
#sending_domain_id ⇒ Object
The sending domain id.
-
#signature_html ⇒ Object
HTML signature appended to every send.
-
#transport_mode ⇒ Object
Returns the value of attribute transport_mode.
-
#transport_provider ⇒ Object
The voice provider key.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VoiceSenderInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VoiceSenderInput
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::VoiceSenderInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::VoiceSenderInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'bcc_crm_email') self.bcc_crm_email = attributes[:'bcc_crm_email'] end if attributes.key?(:'client_label') self.client_label = attributes[:'client_label'] end if attributes.key?(:'daily_limit') self.daily_limit = attributes[:'daily_limit'] end if attributes.key?(:'min_gap_minutes') self.min_gap_minutes = attributes[:'min_gap_minutes'] end if attributes.key?(:'reply_to') self.reply_to = attributes[:'reply_to'] end if attributes.key?(:'sending_domain_id') self.sending_domain_id = attributes[:'sending_domain_id'] end if attributes.key?(:'signature_html') self.signature_html = attributes[:'signature_html'] end if attributes.key?(:'from_email') self.from_email = attributes[:'from_email'] else self.from_email = nil end if attributes.key?(:'from_name') self.from_name = attributes[:'from_name'] else self.from_name = nil end if attributes.key?(:'transport_mode') self.transport_mode = attributes[:'transport_mode'] else self.transport_mode = nil end if attributes.key?(:'transport_provider') self.transport_provider = attributes[:'transport_provider'] end end |
Instance Attribute Details
#bcc_crm_email ⇒ Object
BCC every send to this address (CRM capture).
19 20 21 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 19 def bcc_crm_email @bcc_crm_email end |
#client_label ⇒ Object
Free-text label for this mailbox (e.g. to tag by client).
22 23 24 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 22 def client_label @client_label end |
#daily_limit ⇒ Object
Maximum sends per day for this mailbox.
25 26 27 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 25 def daily_limit @daily_limit end |
#from_email ⇒ Object
The sending address.
40 41 42 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 40 def from_email @from_email end |
#from_name ⇒ Object
Display name.
43 44 45 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 43 def from_name @from_name end |
#min_gap_minutes ⇒ Object
Minimum gap between sends from this mailbox (floor 3; server default 5).
28 29 30 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 28 def min_gap_minutes @min_gap_minutes end |
#reply_to ⇒ Object
Reply-To override.
31 32 33 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 31 def reply_to @reply_to end |
#sending_domain_id ⇒ Object
The sending domain id. Omit to get-or-create it from the fromEmail host.
34 35 36 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 34 def sending_domain_id @sending_domain_id end |
#signature_html ⇒ Object
HTML signature appended to every send.
37 38 39 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 37 def signature_html @signature_html end |
#transport_mode ⇒ Object
Returns the value of attribute transport_mode.
45 46 47 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 45 def transport_mode @transport_mode end |
#transport_provider ⇒ Object
The voice provider key.
48 49 50 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 48 def transport_provider @transport_provider end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 301 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Norbelys.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 51 def self.attribute_map { :'bcc_crm_email' => :'bccCrmEmail', :'client_label' => :'clientLabel', :'daily_limit' => :'dailyLimit', :'min_gap_minutes' => :'minGapMinutes', :'reply_to' => :'replyTo', :'sending_domain_id' => :'sendingDomainId', :'signature_html' => :'signatureHtml', :'from_email' => :'fromEmail', :'from_name' => :'fromName', :'transport_mode' => :'transportMode', :'transport_provider' => :'transportProvider' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 94 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 90 def self.openapi_nullable Set.new([ :'transport_mode', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 73 def self.openapi_types { :'bcc_crm_email' => :'String', :'client_label' => :'String', :'daily_limit' => :'Integer', :'min_gap_minutes' => :'Integer', :'reply_to' => :'String', :'sending_domain_id' => :'String', :'signature_html' => :'String', :'from_email' => :'String', :'from_name' => :'String', :'transport_mode' => :'Object', :'transport_provider' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 246 def ==(o) return true if self.equal?(o) self.class == o.class && bcc_crm_email == o.bcc_crm_email && client_label == o.client_label && daily_limit == o.daily_limit && min_gap_minutes == o.min_gap_minutes && reply_to == o.reply_to && sending_domain_id == o.sending_domain_id && signature_html == o.signature_html && from_email == o.from_email && from_name == o.from_name && transport_mode == o.transport_mode && transport_provider == o.transport_provider end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 372 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 270 def hash [bcc_crm_email, client_label, daily_limit, min_gap_minutes, reply_to, sending_domain_id, signature_html, from_email, from_name, transport_mode, transport_provider].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@daily_limit.nil? && @daily_limit < 0 invalid_properties.push('invalid value for "daily_limit", must be greater than or equal to 0.') end if !@min_gap_minutes.nil? && @min_gap_minutes < 3 invalid_properties.push('invalid value for "min_gap_minutes", must be greater than or equal to 3.') end if @from_email.nil? invalid_properties.push('invalid value for "from_email", from_email cannot be nil.') end if @from_email.to_s.length < 1 invalid_properties.push('invalid value for "from_email", the character length must be great than or equal to 1.') end if @from_name.nil? invalid_properties.push('invalid value for "from_name", from_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
348 349 350 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 348 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 342 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 |
# File 'lib/norbelys/models/voice_sender_input.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@daily_limit.nil? && @daily_limit < 0 return false if !@min_gap_minutes.nil? && @min_gap_minutes < 3 return false if @from_email.nil? return false if @from_email.to_s.length < 1 return false if @from_name.nil? true end |