Class: Norbelys::WarmupRuntimeStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/norbelys/models/warmup_runtime_status.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WarmupRuntimeStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::WarmupRuntimeStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::WarmupRuntimeStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active_conversations')
    self.active_conversations = attributes[:'active_conversations']
  else
    self.active_conversations = nil
  end

  if attributes.key?(:'cohort_id')
    self.cohort_id = attributes[:'cohort_id']
  else
    self.cohort_id = nil
  end

  if attributes.key?(:'cohort_size')
    self.cohort_size = attributes[:'cohort_size']
  else
    self.cohort_size = nil
  end

  if attributes.key?(:'health')
    self.health = attributes[:'health']
  else
    self.health = nil
  end

  if attributes.key?(:'next_rotation_at')
    self.next_rotation_at = attributes[:'next_rotation_at']
  end

  if attributes.key?(:'phase')
    self.phase = attributes[:'phase']
  else
    self.phase = nil
  end

  if attributes.key?(:'ramp_day')
    self.ramp_day = attributes[:'ramp_day']
  else
    self.ramp_day = nil
  end

  if attributes.key?(:'today')
    self.today = attributes[:'today']
  else
    self.today = nil
  end
end

Instance Attribute Details

#active_conversationsObject

Warmup conversations currently in flight for this mailbox.



19
20
21
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 19

def active_conversations
  @active_conversations
end

#cohort_idObject

Returns the value of attribute cohort_id.



21
22
23
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 21

def cohort_id
  @cohort_id
end

#cohort_sizeObject

Number of peer mailboxes in the current cohort (0–10).



24
25
26
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 24

def cohort_size
  @cohort_size
end

#healthObject

Engine-computed warmup health: healthy, degraded, saturated, auth_broken, bouncing, or insufficient_peers.



27
28
29
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 27

def health
  @health
end

#next_rotation_atObject

Returns the value of attribute next_rotation_at.



29
30
31
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 29

def next_rotation_at
  @next_rotation_at
end

#phaseObject

Current warmup lifecycle phase: pending, stable, rotating, paused, or blocked.



32
33
34
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 32

def phase
  @phase
end

#ramp_dayObject

How many days into the warmup ramp this mailbox has progressed.



35
36
37
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 35

def ramp_day
  @ramp_day
end

#todayObject

Returns the value of attribute today.



37
38
39
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 37

def today
  @today
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 353

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Norbelys.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 76

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 62

def self.attribute_map
  {
    :'active_conversations' => :'activeConversations',
    :'cohort_id' => :'cohortId',
    :'cohort_size' => :'cohortSize',
    :'health' => :'health',
    :'next_rotation_at' => :'nextRotationAt',
    :'phase' => :'phase',
    :'ramp_day' => :'rampDay',
    :'today' => :'today'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 329

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
99
100
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 95

def self.openapi_nullable
  Set.new([
    :'cohort_id',
    :'next_rotation_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 81

def self.openapi_types
  {
    :'active_conversations' => :'Integer',
    :'cohort_id' => :'String',
    :'cohort_size' => :'Integer',
    :'health' => :'String',
    :'next_rotation_at' => :'Object',
    :'phase' => :'String',
    :'ramp_day' => :'Integer',
    :'today' => :'WarmupTodayTally'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active_conversations == o.active_conversations &&
      cohort_id == o.cohort_id &&
      cohort_size == o.cohort_size &&
      health == o.health &&
      next_rotation_at == o.next_rotation_at &&
      phase == o.phase &&
      ramp_day == o.ramp_day &&
      today == o.today
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 424

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


316
317
318
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 316

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



322
323
324
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 322

def hash
  [active_conversations, cohort_id, cohort_size, health, next_rotation_at, phase, ramp_day, today].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @active_conversations.nil?
    invalid_properties.push('invalid value for "active_conversations", active_conversations cannot be nil.')
  end

  if @active_conversations < 0
    invalid_properties.push('invalid value for "active_conversations", must be greater than or equal to 0.')
  end

  if @cohort_size.nil?
    invalid_properties.push('invalid value for "cohort_size", cohort_size cannot be nil.')
  end

  if @cohort_size > 10
    invalid_properties.push('invalid value for "cohort_size", must be smaller than or equal to 10.')
  end

  if @cohort_size < 0
    invalid_properties.push('invalid value for "cohort_size", must be greater than or equal to 0.')
  end

  if @health.nil?
    invalid_properties.push('invalid value for "health", health cannot be nil.')
  end

  if @phase.nil?
    invalid_properties.push('invalid value for "phase", phase cannot be nil.')
  end

  if @ramp_day.nil?
    invalid_properties.push('invalid value for "ramp_day", ramp_day cannot be nil.')
  end

  if @ramp_day < 0
    invalid_properties.push('invalid value for "ramp_day", must be greater than or equal to 0.')
  end

  if @today.nil?
    invalid_properties.push('invalid value for "today", today cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



400
401
402
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 400

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 406

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



394
395
396
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 394

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/norbelys/models/warmup_runtime_status.rb', line 214

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @active_conversations.nil?
  return false if @active_conversations < 0
  return false if @cohort_size.nil?
  return false if @cohort_size > 10
  return false if @cohort_size < 0
  return false if @health.nil?
  health_validator = EnumAttributeValidator.new('String', ["healthy", "degraded", "saturated", "auth_broken", "bouncing", "insufficient_peers"])
  return false unless health_validator.valid?(@health)
  return false if @phase.nil?
  phase_validator = EnumAttributeValidator.new('String', ["pending", "stable", "rotating", "paused", "blocked"])
  return false unless phase_validator.valid?(@phase)
  return false if @ramp_day.nil?
  return false if @ramp_day < 0
  return false if @today.nil?
  true
end