Class: Norbelys::DomainSendingPolicy
- Inherits:
-
Object
- Object
- Norbelys::DomainSendingPolicy
- Defined in:
- lib/norbelys/models/domain_sending_policy.rb
Overview
The daily-budget control policy.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allow_pause_all ⇒ Object
Whether the platform may pause ALL sends from this domain when health is critical.
-
#allow_pause_first_touches ⇒ Object
Whether the platform may pause first-touch (cold) sends while replies keep flowing.
-
#autopilot_max ⇒ Object
Returns the value of attribute autopilot_max.
-
#autopilot_min ⇒ Object
Returns the value of attribute autopilot_min.
-
#configured_daily_cap ⇒ Object
Returns the value of attribute configured_daily_cap.
-
#effective_daily_cap ⇒ Object
Returns the value of attribute effective_daily_cap.
-
#max_daily_growth_percent ⇒ Object
Returns the value of attribute max_daily_growth_percent.
-
#mode ⇒ Object
Budget control mode:
legacy,manual, orautopilot. -
#recommended_daily_cap ⇒ Object
Returns the value of attribute recommended_daily_cap.
-
#timezone ⇒ Object
IANA timezone the daily window and reset are computed in.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainSendingPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainSendingPolicy
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::DomainSendingPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::DomainSendingPolicy`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allow_pause_all') self.allow_pause_all = attributes[:'allow_pause_all'] else self.allow_pause_all = nil end if attributes.key?(:'allow_pause_first_touches') self.allow_pause_first_touches = attributes[:'allow_pause_first_touches'] else self.allow_pause_first_touches = nil end if attributes.key?(:'autopilot_max') self.autopilot_max = attributes[:'autopilot_max'] else self.autopilot_max = nil end if attributes.key?(:'autopilot_min') self.autopilot_min = attributes[:'autopilot_min'] else self.autopilot_min = nil end if attributes.key?(:'configured_daily_cap') self.configured_daily_cap = attributes[:'configured_daily_cap'] else self.configured_daily_cap = nil end if attributes.key?(:'effective_daily_cap') self.effective_daily_cap = attributes[:'effective_daily_cap'] else self.effective_daily_cap = nil end if attributes.key?(:'max_daily_growth_percent') self.max_daily_growth_percent = attributes[:'max_daily_growth_percent'] else self.max_daily_growth_percent = nil end if attributes.key?(:'mode') self.mode = attributes[:'mode'] else self.mode = nil end if attributes.key?(:'recommended_daily_cap') self.recommended_daily_cap = attributes[:'recommended_daily_cap'] else self.recommended_daily_cap = nil end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] else self.timezone = nil end end |
Instance Attribute Details
#allow_pause_all ⇒ Object
Whether the platform may pause ALL sends from this domain when health is critical.
20 21 22 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 20 def allow_pause_all @allow_pause_all end |
#allow_pause_first_touches ⇒ Object
Whether the platform may pause first-touch (cold) sends while replies keep flowing.
23 24 25 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 23 def allow_pause_first_touches @allow_pause_first_touches end |
#autopilot_max ⇒ Object
Returns the value of attribute autopilot_max.
25 26 27 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 25 def autopilot_max @autopilot_max end |
#autopilot_min ⇒ Object
Returns the value of attribute autopilot_min.
27 28 29 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 27 def autopilot_min @autopilot_min end |
#configured_daily_cap ⇒ Object
Returns the value of attribute configured_daily_cap.
29 30 31 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 29 def configured_daily_cap @configured_daily_cap end |
#effective_daily_cap ⇒ Object
Returns the value of attribute effective_daily_cap.
31 32 33 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 31 def effective_daily_cap @effective_daily_cap end |
#max_daily_growth_percent ⇒ Object
Returns the value of attribute max_daily_growth_percent.
33 34 35 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 33 def max_daily_growth_percent @max_daily_growth_percent end |
#mode ⇒ Object
Budget control mode: legacy, manual, or autopilot.
36 37 38 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 36 def mode @mode end |
#recommended_daily_cap ⇒ Object
Returns the value of attribute recommended_daily_cap.
38 39 40 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 38 def recommended_daily_cap @recommended_daily_cap end |
#timezone ⇒ Object
IANA timezone the daily window and reset are computed in.
41 42 43 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 41 def timezone @timezone end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 392 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Norbelys.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 82 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 66 def self.attribute_map { :'allow_pause_all' => :'allowPauseAll', :'allow_pause_first_touches' => :'allowPauseFirstTouches', :'autopilot_max' => :'autopilotMax', :'autopilot_min' => :'autopilotMin', :'configured_daily_cap' => :'configuredDailyCap', :'effective_daily_cap' => :'effectiveDailyCap', :'max_daily_growth_percent' => :'maxDailyGrowthPercent', :'mode' => :'mode', :'recommended_daily_cap' => :'recommendedDailyCap', :'timezone' => :'timezone' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 368 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 103 def self.openapi_nullable Set.new([ :'autopilot_max', :'autopilot_min', :'configured_daily_cap', :'effective_daily_cap', :'max_daily_growth_percent', :'recommended_daily_cap', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 87 def self.openapi_types { :'allow_pause_all' => :'Boolean', :'allow_pause_first_touches' => :'Boolean', :'autopilot_max' => :'Integer', :'autopilot_min' => :'Integer', :'configured_daily_cap' => :'Integer', :'effective_daily_cap' => :'Integer', :'max_daily_growth_percent' => :'Integer', :'mode' => :'String', :'recommended_daily_cap' => :'Integer', :'timezone' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 338 def ==(o) return true if self.equal?(o) self.class == o.class && allow_pause_all == o.allow_pause_all && allow_pause_first_touches == o.allow_pause_first_touches && autopilot_max == o.autopilot_max && autopilot_min == o.autopilot_min && configured_daily_cap == o.configured_daily_cap && effective_daily_cap == o.effective_daily_cap && max_daily_growth_percent == o.max_daily_growth_percent && mode == o.mode && recommended_daily_cap == o.recommended_daily_cap && timezone == o.timezone end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 463 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
355 356 357 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 355 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
361 362 363 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 361 def hash [allow_pause_all, allow_pause_first_touches, autopilot_max, autopilot_min, configured_daily_cap, effective_daily_cap, max_daily_growth_percent, mode, recommended_daily_cap, timezone].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 192 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @allow_pause_all.nil? invalid_properties.push('invalid value for "allow_pause_all", allow_pause_all cannot be nil.') end if @allow_pause_first_touches.nil? invalid_properties.push('invalid value for "allow_pause_first_touches", allow_pause_first_touches cannot be nil.') end if @autopilot_max < 0 invalid_properties.push('invalid value for "autopilot_max", must be greater than or equal to 0.') end if @autopilot_min < 0 invalid_properties.push('invalid value for "autopilot_min", must be greater than or equal to 0.') end if @configured_daily_cap < 0 invalid_properties.push('invalid value for "configured_daily_cap", must be greater than or equal to 0.') end if @effective_daily_cap < 0 invalid_properties.push('invalid value for "effective_daily_cap", must be greater than or equal to 0.') end if @max_daily_growth_percent > 100 invalid_properties.push('invalid value for "max_daily_growth_percent", must be smaller than or equal to 100.') end if @max_daily_growth_percent < 0 invalid_properties.push('invalid value for "max_daily_growth_percent", must be greater than or equal to 0.') end if @mode.nil? invalid_properties.push('invalid value for "mode", mode cannot be nil.') end if @recommended_daily_cap < 0 invalid_properties.push('invalid value for "recommended_daily_cap", must be greater than or equal to 0.') end if @timezone.nil? invalid_properties.push('invalid value for "timezone", timezone cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
439 440 441 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 439 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
445 446 447 448 449 450 451 452 453 454 455 456 457 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 445 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
433 434 435 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 433 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/norbelys/models/domain_sending_policy.rb', line 244 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @allow_pause_all.nil? return false if @allow_pause_first_touches.nil? return false if @autopilot_max < 0 return false if @autopilot_min < 0 return false if @configured_daily_cap < 0 return false if @effective_daily_cap < 0 return false if @max_daily_growth_percent > 100 return false if @max_daily_growth_percent < 0 return false if @mode.nil? mode_validator = EnumAttributeValidator.new('String', ["legacy", "manual", "autopilot"]) return false unless mode_validator.valid?(@mode) return false if @recommended_daily_cap < 0 return false if @timezone.nil? true end |