Class: Norbelys::GroupsApi
- Inherits:
-
Object
- Object
- Norbelys::GroupsApi
- Defined in:
- lib/norbelys/api/groups_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#groups_archive(id, opts = {}) ⇒ Group
Delete a group Permanently delete the group and its membership rows.
-
#groups_archive_with_http_info(id, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Delete a group Permanently delete the group and its membership rows.
-
#groups_create(group_create_params, opts = {}) ⇒ Group
Create a group Create a group: an empty static list of people.
-
#groups_create_with_http_info(group_create_params, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Create a group Create a group: an empty static list of people.
-
#groups_find(id, opts = {}) ⇒ Group
Get a group Read one group, including its live member count.
-
#groups_find_with_http_info(id, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Get a group Read one group, including its live member count.
-
#groups_list(opts = {}) ⇒ GroupList
List groups List the org's groups — static, hand-curated lists of people — newest first.
-
#groups_list_with_http_info(opts = {}) ⇒ Array<(GroupList, Integer, Hash)>
List groups List the org's groups — static, hand-curated lists of people — newest first.
-
#groups_members_add(id, opts = {}) ⇒ GroupAddMembersResult
Add people to a group Add people to the group by explicit person ids and/or by snapshotting a segment's current matches into it.
-
#groups_members_add_with_http_info(id, opts = {}) ⇒ Array<(GroupAddMembersResult, Integer, Hash)>
Add people to a group Add people to the group by explicit person ids and/or by snapshotting a segment's current matches into it.
-
#groups_members_remove(id, rel_id, opts = {}) ⇒ DetachResult
Remove a person from a group Remove one person from the group.
-
#groups_members_remove_with_http_info(id, rel_id, opts = {}) ⇒ Array<(DetachResult, Integer, Hash)>
Remove a person from a group Remove one person from the group.
-
#groups_update(id, opts = {}) ⇒ Group
Update a group Rename a group or change its description and color chip.
-
#groups_update_with_http_info(id, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Update a group Rename a group or change its description and color chip.
-
#initialize(api_client = ApiClient.default) ⇒ GroupsApi
constructor
A new instance of GroupsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/norbelys/api/groups_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#groups_archive(id, opts = {}) ⇒ Group
Delete a group Permanently delete the group and its membership rows. The people themselves are kept — only their membership in this group is removed.
27 28 29 30 |
# File 'lib/norbelys/api/groups_api.rb', line 27 def groups_archive(id, opts = {}) data, _status_code, _headers = groups_archive_with_http_info(id, opts) data end |
#groups_archive_with_http_info(id, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Delete a group Permanently delete the group and its membership rows. The people themselves are kept — only their membership in this group is removed.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/norbelys/api/groups_api.rb', line 37 def groups_archive_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupsApi.groups_archive ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GroupsApi.groups_archive" end # resource path local_var_path = '/groups/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Group' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GroupsApi.groups_archive", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupsApi#groups_archive\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#groups_create(group_create_params, opts = {}) ⇒ Group
Create a group Create a group: an empty static list of people. Add members with groups.members.add (explicit person ids, or snapshot a segment's current matches), then view them at GET /v1/people?groupId=id.
91 92 93 94 |
# File 'lib/norbelys/api/groups_api.rb', line 91 def groups_create(group_create_params, opts = {}) data, _status_code, _headers = groups_create_with_http_info(group_create_params, opts) data end |
#groups_create_with_http_info(group_create_params, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Create a group Create a group: an empty static list of people. Add members with groups.members.add (explicit person ids, or snapshot a segment's current matches), then view them at GET /v1/people?groupId=id.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/norbelys/api/groups_api.rb', line 102 def groups_create_with_http_info(group_create_params, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupsApi.groups_create ...' end # verify the required parameter 'group_create_params' is set if @api_client.config.client_side_validation && group_create_params.nil? fail ArgumentError, "Missing the required parameter 'group_create_params' when calling GroupsApi.groups_create" end if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling GroupsApi.groups_create, the character length must be smaller than or equal to 255.' end # resource path local_var_path = '/groups' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(group_create_params) # return_type return_type = opts[:debug_return_type] || 'Group' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GroupsApi.groups_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupsApi#groups_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#groups_find(id, opts = {}) ⇒ Group
Get a group Read one group, including its live member count. List its members at GET /v1/people?groupId=id — there is no separate members endpoint.
165 166 167 168 |
# File 'lib/norbelys/api/groups_api.rb', line 165 def groups_find(id, opts = {}) data, _status_code, _headers = groups_find_with_http_info(id, opts) data end |
#groups_find_with_http_info(id, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Get a group Read one group, including its live member count. List its members at GET /v1/people?groupId=id — there is no separate members endpoint.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/norbelys/api/groups_api.rb', line 175 def groups_find_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupsApi.groups_find ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GroupsApi.groups_find" end # resource path local_var_path = '/groups/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Group' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GroupsApi.groups_find", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupsApi#groups_find\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#groups_list(opts = {}) ⇒ GroupList
List groups List the org's groups — static, hand-curated lists of people — newest first.
231 232 233 234 |
# File 'lib/norbelys/api/groups_api.rb', line 231 def groups_list(opts = {}) data, _status_code, _headers = groups_list_with_http_info(opts) data end |
#groups_list_with_http_info(opts = {}) ⇒ Array<(GroupList, Integer, Hash)>
List groups List the org's groups — static, hand-curated lists of people — newest first.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/norbelys/api/groups_api.rb', line 244 def groups_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupsApi.groups_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling GroupsApi.groups_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling GroupsApi.groups_list, must be greater than or equal to 1.' end # resource path local_var_path = '/groups' # query parameters query_params = opts[:query_params] || {} query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'includeArchived'] = opts[:'include_archived'] if !opts[:'include_archived'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GroupList' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GroupsApi.groups_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupsApi#groups_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#groups_members_add(id, opts = {}) ⇒ GroupAddMembersResult
Add people to a group Add people to the group by explicit person ids and/or by snapshotting a segment's current matches into it. Idempotent — people already in the group are skipped.
307 308 309 310 |
# File 'lib/norbelys/api/groups_api.rb', line 307 def groups_members_add(id, opts = {}) data, _status_code, _headers = groups_members_add_with_http_info(id, opts) data end |
#groups_members_add_with_http_info(id, opts = {}) ⇒ Array<(GroupAddMembersResult, Integer, Hash)>
Add people to a group Add people to the group by explicit person ids and/or by snapshotting a segment's current matches into it. Idempotent — people already in the group are skipped.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/norbelys/api/groups_api.rb', line 319 def groups_members_add_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupsApi.groups_members_add ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GroupsApi.groups_members_add" end if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling GroupsApi.groups_members_add, the character length must be smaller than or equal to 255.' end # resource path local_var_path = '/groups/{id}/members'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'group_add_members_params']) # return_type return_type = opts[:debug_return_type] || 'GroupAddMembersResult' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GroupsApi.groups_members_add", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupsApi#groups_members_add\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#groups_members_remove(id, rel_id, opts = {}) ⇒ DetachResult
Remove a person from a group Remove one person from the group. The person record is kept — only their membership in this group is removed.
383 384 385 386 |
# File 'lib/norbelys/api/groups_api.rb', line 383 def groups_members_remove(id, rel_id, opts = {}) data, _status_code, _headers = groups_members_remove_with_http_info(id, rel_id, opts) data end |
#groups_members_remove_with_http_info(id, rel_id, opts = {}) ⇒ Array<(DetachResult, Integer, Hash)>
Remove a person from a group Remove one person from the group. The person record is kept — only their membership in this group is removed.
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/norbelys/api/groups_api.rb', line 394 def groups_members_remove_with_http_info(id, rel_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupsApi.groups_members_remove ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GroupsApi.groups_members_remove" end # verify the required parameter 'rel_id' is set if @api_client.config.client_side_validation && rel_id.nil? fail ArgumentError, "Missing the required parameter 'rel_id' when calling GroupsApi.groups_members_remove" end # resource path local_var_path = '/groups/{id}/members/{relId}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'relId' + '}', CGI.escape(rel_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DetachResult' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GroupsApi.groups_members_remove", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupsApi#groups_members_remove\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#groups_update(id, opts = {}) ⇒ Group
Update a group Rename a group or change its description and color chip. Membership is edited separately via groups.members.add / groups.members.remove.
452 453 454 455 |
# File 'lib/norbelys/api/groups_api.rb', line 452 def groups_update(id, opts = {}) data, _status_code, _headers = groups_update_with_http_info(id, opts) data end |
#groups_update_with_http_info(id, opts = {}) ⇒ Array<(Group, Integer, Hash)>
Update a group Rename a group or change its description and color chip. Membership is edited separately via groups.members.add / groups.members.remove.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 |
# File 'lib/norbelys/api/groups_api.rb', line 463 def groups_update_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupsApi.groups_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GroupsApi.groups_update" end # resource path local_var_path = '/groups/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'group_update_params']) # return_type return_type = opts[:debug_return_type] || 'Group' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GroupsApi.groups_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupsApi#groups_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |