Class: Norbelys::IntegrationsApi
- Inherits:
-
Object
- Object
- Norbelys::IntegrationsApi
- Defined in:
- lib/norbelys/api/integrations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ IntegrationsApi
constructor
A new instance of IntegrationsApi.
-
#integrations_connect(integration_connect_params, opts = {}) ⇒ IntegrationConnectResult
Connect an integration Mints a Nango Connect session for the provider and returns its
sessionTokenfor the frontend Connect UI. -
#integrations_connect_with_http_info(integration_connect_params, opts = {}) ⇒ Array<(IntegrationConnectResult, Integer, Hash)>
Connect an integration Mints a Nango Connect session for the provider and returns its `sessionToken` for the frontend Connect UI.
-
#integrations_find(id, opts = {}) ⇒ Integration
Get an integration.
-
#integrations_find_with_http_info(id, opts = {}) ⇒ Array<(Integration, Integer, Hash)>
Get an integration.
-
#integrations_list(opts = {}) ⇒ IntegrationList
List integrations Each row is one connected provider account.
-
#integrations_list_with_http_info(opts = {}) ⇒ Array<(IntegrationList, Integer, Hash)>
List integrations Each row is one connected provider account.
-
#integrations_options(id, opts = {}) ⇒ IntegrationOptions
List an integration's config options Config-time lookup of the provider's selectable options, proxied live through Nango — today, the postable Slack channels for the notification channel picker.
-
#integrations_options_with_http_info(id, opts = {}) ⇒ Array<(IntegrationOptions, Integer, Hash)>
List an integration's config options Config-time lookup of the provider's selectable options, proxied live through Nango — today, the postable Slack channels for the notification channel picker.
-
#integrations_remove(id, opts = {}) ⇒ Integration
Disconnect an integration Disconnects the account: revokes the credential at the provider via Nango and soft-archives the row.
-
#integrations_remove_with_http_info(id, opts = {}) ⇒ Array<(Integration, Integer, Hash)>
Disconnect an integration Disconnects the account: revokes the credential at the provider via Nango and soft-archives the row.
-
#integrations_sync(id, opts = {}) ⇒ IntegrationSyncResult
Sync an integration now Triggers an immediate, off-schedule sync, queuing a drain of every model the provider syncs (e.g. leads and deals for a CRM).
-
#integrations_sync_with_http_info(id, opts = {}) ⇒ Array<(IntegrationSyncResult, Integer, Hash)>
Sync an integration now Triggers an immediate, off-schedule sync, queuing a drain of every model the provider syncs (e.g. leads and deals for a CRM).
-
#integrations_update(id, integration_update_params, opts = {}) ⇒ Integration
Update an integration Shallow-merges the given
configover the stored config (top-level keys replace). -
#integrations_update_with_http_info(id, integration_update_params, opts = {}) ⇒ Array<(Integration, Integer, Hash)>
Update an integration Shallow-merges the given `config` over the stored config (top-level keys replace).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IntegrationsApi
Returns a new instance of IntegrationsApi.
19 20 21 |
# File 'lib/norbelys/api/integrations_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/norbelys/api/integrations_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#integrations_connect(integration_connect_params, opts = {}) ⇒ IntegrationConnectResult
Connect an integration
Mints a Nango Connect session for the provider and returns its sessionToken for the frontend Connect UI. There is no direct create — the connection row is born from the provider's auth webhook once the user finishes authorizing.
28 29 30 31 |
# File 'lib/norbelys/api/integrations_api.rb', line 28 def integrations_connect(integration_connect_params, opts = {}) data, _status_code, _headers = integrations_connect_with_http_info(integration_connect_params, opts) data end |
#integrations_connect_with_http_info(integration_connect_params, opts = {}) ⇒ Array<(IntegrationConnectResult, Integer, Hash)>
Connect an integration Mints a Nango Connect session for the provider and returns its `sessionToken` for the frontend Connect UI. There is no direct create — the connection row is born from the provider's auth webhook once the user finishes authorizing.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/norbelys/api/integrations_api.rb', line 39 def integrations_connect_with_http_info(integration_connect_params, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_connect ...' end # verify the required parameter 'integration_connect_params' is set if @api_client.config.client_side_validation && integration_connect_params.nil? fail ArgumentError, "Missing the required parameter 'integration_connect_params' when calling IntegrationsApi.integrations_connect" end if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling IntegrationsApi.integrations_connect, the character length must be smaller than or equal to 255.' end # resource path local_var_path = '/integrations/connect' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(integration_connect_params) # return_type return_type = opts[:debug_return_type] || 'IntegrationConnectResult' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IntegrationsApi.integrations_connect", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_connect\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#integrations_find(id, opts = {}) ⇒ Integration
Get an integration
101 102 103 104 |
# File 'lib/norbelys/api/integrations_api.rb', line 101 def integrations_find(id, opts = {}) data, _status_code, _headers = integrations_find_with_http_info(id, opts) data end |
#integrations_find_with_http_info(id, opts = {}) ⇒ Array<(Integration, Integer, Hash)>
Get an integration
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/norbelys/api/integrations_api.rb', line 110 def integrations_find_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_find ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling IntegrationsApi.integrations_find" end # resource path local_var_path = '/integrations/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Integration' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IntegrationsApi.integrations_find", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_find\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#integrations_list(opts = {}) ⇒ IntegrationList
List integrations
Each row is one connected provider account. There is no create endpoint — a connection is born from the provider's auth webhook after you call connect.
166 167 168 169 |
# File 'lib/norbelys/api/integrations_api.rb', line 166 def integrations_list(opts = {}) data, _status_code, _headers = integrations_list_with_http_info(opts) data end |
#integrations_list_with_http_info(opts = {}) ⇒ Array<(IntegrationList, Integer, Hash)>
List integrations Each row is one connected provider account. There is no create endpoint — a connection is born from the provider's auth webhook after you call `connect`.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/norbelys/api/integrations_api.rb', line 179 def integrations_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_list ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling IntegrationsApi.integrations_list, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling IntegrationsApi.integrations_list, must be greater than or equal to 1.' end allowable_values = ["slack", "hubspot", "pipedrive", "salesforce", "calendly", "calcom", "google-calendar", "zoho-calendar", "acuity-scheduling", "youcanbook-me", "apollo", "smartlead", "instantly", "lemlist"] if @api_client.config.client_side_validation && opts[:'provider'] && !allowable_values.include?(opts[:'provider']) fail ArgumentError, "invalid value for \"provider\", must be one of #{allowable_values}" end # resource path local_var_path = '/integrations' # query parameters query_params = opts[:query_params] || {} query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'includeArchived'] = opts[:'include_archived'] if !opts[:'include_archived'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'provider'] = opts[:'provider'] if !opts[:'provider'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IntegrationList' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IntegrationsApi.integrations_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#integrations_options(id, opts = {}) ⇒ IntegrationOptions
List an integration's config options Config-time lookup of the provider's selectable options, proxied live through Nango — today, the postable Slack channels for the notification channel picker.
244 245 246 247 |
# File 'lib/norbelys/api/integrations_api.rb', line 244 def (id, opts = {}) data, _status_code, _headers = (id, opts) data end |
#integrations_options_with_http_info(id, opts = {}) ⇒ Array<(IntegrationOptions, Integer, Hash)>
List an integration's config options Config-time lookup of the provider's selectable options, proxied live through Nango — today, the postable Slack channels for the notification channel picker.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/norbelys/api/integrations_api.rb', line 254 def (id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_options ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling IntegrationsApi.integrations_options" end # resource path local_var_path = '/integrations/{id}/options'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IntegrationOptions' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IntegrationsApi.integrations_options", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_options\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#integrations_remove(id, opts = {}) ⇒ Integration
Disconnect an integration Disconnects the account: revokes the credential at the provider via Nango and soft-archives the row.
307 308 309 310 |
# File 'lib/norbelys/api/integrations_api.rb', line 307 def integrations_remove(id, opts = {}) data, _status_code, _headers = integrations_remove_with_http_info(id, opts) data end |
#integrations_remove_with_http_info(id, opts = {}) ⇒ Array<(Integration, Integer, Hash)>
Disconnect an integration Disconnects the account: revokes the credential at the provider via Nango and soft-archives the row.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/norbelys/api/integrations_api.rb', line 317 def integrations_remove_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_remove ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling IntegrationsApi.integrations_remove" end # resource path local_var_path = '/integrations/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Integration' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IntegrationsApi.integrations_remove", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_remove\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#integrations_sync(id, opts = {}) ⇒ IntegrationSyncResult
Sync an integration now Triggers an immediate, off-schedule sync, queuing a drain of every model the provider syncs (e.g. leads and deals for a CRM).
371 372 373 374 |
# File 'lib/norbelys/api/integrations_api.rb', line 371 def integrations_sync(id, opts = {}) data, _status_code, _headers = integrations_sync_with_http_info(id, opts) data end |
#integrations_sync_with_http_info(id, opts = {}) ⇒ Array<(IntegrationSyncResult, Integer, Hash)>
Sync an integration now Triggers an immediate, off-schedule sync, queuing a drain of every model the provider syncs (e.g. leads and deals for a CRM).
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/norbelys/api/integrations_api.rb', line 382 def integrations_sync_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_sync ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling IntegrationsApi.integrations_sync" end if @api_client.config.client_side_validation && !opts[:'idempotency_key'].nil? && opts[:'idempotency_key'].to_s.length > 255 fail ArgumentError, 'invalid value for "opts[:"idempotency_key"]" when calling IntegrationsApi.integrations_sync, the character length must be smaller than or equal to 255.' end # resource path local_var_path = '/integrations/{id}/sync'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IntegrationSyncResult' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IntegrationsApi.integrations_sync", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_sync\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#integrations_update(id, integration_update_params, opts = {}) ⇒ Integration
Update an integration
Shallow-merges the given config over the stored config (top-level keys replace). Slack carries the notification toggles and target channel; CRMs carry the sync-in / push-out direction gates.
441 442 443 444 |
# File 'lib/norbelys/api/integrations_api.rb', line 441 def integrations_update(id, integration_update_params, opts = {}) data, _status_code, _headers = integrations_update_with_http_info(id, integration_update_params, opts) data end |
#integrations_update_with_http_info(id, integration_update_params, opts = {}) ⇒ Array<(Integration, Integer, Hash)>
Update an integration Shallow-merges the given `config` over the stored config (top-level keys replace). Slack carries the notification toggles and target channel; CRMs carry the sync-in / push-out direction gates.
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/norbelys/api/integrations_api.rb', line 452 def integrations_update_with_http_info(id, integration_update_params, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsApi.integrations_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling IntegrationsApi.integrations_update" end # verify the required parameter 'integration_update_params' is set if @api_client.config.client_side_validation && integration_update_params.nil? fail ArgumentError, "Missing the required parameter 'integration_update_params' when calling IntegrationsApi.integrations_update" end # resource path local_var_path = '/integrations/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(integration_update_params) # return_type return_type = opts[:debug_return_type] || 'Integration' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"IntegrationsApi.integrations_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsApi#integrations_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |