Class: Norbelys::OutboundMessage
- Inherits:
-
Object
- Object
- Norbelys::OutboundMessage
- Defined in:
- lib/norbelys/models/outbound_message.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#channel ⇒ Object
Outbound channel: email, call, sms, or linkedin.
-
#contact_email ⇒ Object
Returns the value of attribute contact_email.
-
#contact_name ⇒ Object
Returns the value of attribute contact_name.
-
#direction ⇒ Object
Returns the value of attribute direction.
-
#id ⇒ Object
The message id.
-
#is_test ⇒ Object
A test/probe send — surfaced in the log but excluded from campaign rates.
-
#object ⇒ Object
Returns the value of attribute object.
-
#occurred_at ⇒ Object
Returns the value of attribute occurred_at.
-
#person_id ⇒ Object
Returns the value of attribute person_id.
-
#program_id ⇒ Object
Returns the value of attribute program_id.
-
#sender_id ⇒ Object
Returns the value of attribute sender_id.
-
#status ⇒ Object
Delivery status: queued, sent, delivered, failed, bounced, or cancelled.
-
#step_id ⇒ Object
Returns the value of attribute step_id.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#thread_id ⇒ Object
Returns the value of attribute thread_id.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OutboundMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OutboundMessage
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/norbelys/models/outbound_message.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::OutboundMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::OutboundMessage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'contact_email') self.contact_email = attributes[:'contact_email'] else self.contact_email = nil end if attributes.key?(:'contact_name') self.contact_name = attributes[:'contact_name'] else self.contact_name = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'occurred_at') self.occurred_at = attributes[:'occurred_at'] end if attributes.key?(:'person_id') self.person_id = attributes[:'person_id'] else self.person_id = nil end if attributes.key?(:'sender_id') self.sender_id = attributes[:'sender_id'] else self.sender_id = nil end if attributes.key?(:'subject') self.subject = attributes[:'subject'] else self.subject = nil end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] else self.thread_id = nil end if attributes.key?(:'channel') self.channel = attributes[:'channel'] else self.channel = nil end if attributes.key?(:'direction') self.direction = attributes[:'direction'] else self.direction = nil end if attributes.key?(:'is_test') self.is_test = attributes[:'is_test'] else self.is_test = nil end if attributes.key?(:'program_id') self.program_id = attributes[:'program_id'] else self.program_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'step_id') self.step_id = attributes[:'step_id'] else self.step_id = nil end end |
Instance Attribute Details
#channel ⇒ Object
Outbound channel: email, call, sms, or linkedin.
38 39 40 |
# File 'lib/norbelys/models/outbound_message.rb', line 38 def channel @channel end |
#contact_email ⇒ Object
Returns the value of attribute contact_email.
18 19 20 |
# File 'lib/norbelys/models/outbound_message.rb', line 18 def contact_email @contact_email end |
#contact_name ⇒ Object
Returns the value of attribute contact_name.
20 21 22 |
# File 'lib/norbelys/models/outbound_message.rb', line 20 def contact_name @contact_name end |
#direction ⇒ Object
Returns the value of attribute direction.
40 41 42 |
# File 'lib/norbelys/models/outbound_message.rb', line 40 def direction @direction end |
#id ⇒ Object
The message id.
23 24 25 |
# File 'lib/norbelys/models/outbound_message.rb', line 23 def id @id end |
#is_test ⇒ Object
A test/probe send — surfaced in the log but excluded from campaign rates.
43 44 45 |
# File 'lib/norbelys/models/outbound_message.rb', line 43 def is_test @is_test end |
#object ⇒ Object
Returns the value of attribute object.
25 26 27 |
# File 'lib/norbelys/models/outbound_message.rb', line 25 def object @object end |
#occurred_at ⇒ Object
Returns the value of attribute occurred_at.
27 28 29 |
# File 'lib/norbelys/models/outbound_message.rb', line 27 def occurred_at @occurred_at end |
#person_id ⇒ Object
Returns the value of attribute person_id.
29 30 31 |
# File 'lib/norbelys/models/outbound_message.rb', line 29 def person_id @person_id end |
#program_id ⇒ Object
Returns the value of attribute program_id.
45 46 47 |
# File 'lib/norbelys/models/outbound_message.rb', line 45 def program_id @program_id end |
#sender_id ⇒ Object
Returns the value of attribute sender_id.
31 32 33 |
# File 'lib/norbelys/models/outbound_message.rb', line 31 def sender_id @sender_id end |
#status ⇒ Object
Delivery status: queued, sent, delivered, failed, bounced, or cancelled.
48 49 50 |
# File 'lib/norbelys/models/outbound_message.rb', line 48 def status @status end |
#step_id ⇒ Object
Returns the value of attribute step_id.
50 51 52 |
# File 'lib/norbelys/models/outbound_message.rb', line 50 def step_id @step_id end |
#subject ⇒ Object
Returns the value of attribute subject.
33 34 35 |
# File 'lib/norbelys/models/outbound_message.rb', line 33 def subject @subject end |
#thread_id ⇒ Object
Returns the value of attribute thread_id.
35 36 37 |
# File 'lib/norbelys/models/outbound_message.rb', line 35 def thread_id @thread_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/norbelys/models/outbound_message.rb', line 360 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Norbelys.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/norbelys/models/outbound_message.rb', line 96 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/norbelys/models/outbound_message.rb', line 75 def self.attribute_map { :'contact_email' => :'contactEmail', :'contact_name' => :'contactName', :'id' => :'id', :'object' => :'object', :'occurred_at' => :'occurredAt', :'person_id' => :'personId', :'sender_id' => :'senderId', :'subject' => :'subject', :'thread_id' => :'threadId', :'channel' => :'channel', :'direction' => :'direction', :'is_test' => :'isTest', :'program_id' => :'programId', :'status' => :'status', :'step_id' => :'stepId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/norbelys/models/outbound_message.rb', line 336 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/norbelys/models/outbound_message.rb', line 122 def self.openapi_nullable Set.new([ :'contact_email', :'contact_name', :'object', :'occurred_at', :'person_id', :'sender_id', :'subject', :'thread_id', :'direction', :'program_id', :'step_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/norbelys/models/outbound_message.rb', line 101 def self.openapi_types { :'contact_email' => :'String', :'contact_name' => :'String', :'id' => :'String', :'object' => :'Object', :'occurred_at' => :'Object', :'person_id' => :'String', :'sender_id' => :'String', :'subject' => :'String', :'thread_id' => :'String', :'channel' => :'String', :'direction' => :'Object', :'is_test' => :'Boolean', :'program_id' => :'String', :'status' => :'String', :'step_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/norbelys/models/outbound_message.rb', line 301 def ==(o) return true if self.equal?(o) self.class == o.class && contact_email == o.contact_email && contact_name == o.contact_name && id == o.id && object == o.object && occurred_at == o.occurred_at && person_id == o.person_id && sender_id == o.sender_id && subject == o.subject && thread_id == o.thread_id && channel == o.channel && direction == o.direction && is_test == o.is_test && program_id == o.program_id && status == o.status && step_id == o.step_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
431 432 433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/norbelys/models/outbound_message.rb', line 431 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
323 324 325 |
# File 'lib/norbelys/models/outbound_message.rb', line 323 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
329 330 331 |
# File 'lib/norbelys/models/outbound_message.rb', line 329 def hash [contact_email, contact_name, id, object, occurred_at, person_id, sender_id, subject, thread_id, channel, direction, is_test, program_id, status, step_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/norbelys/models/outbound_message.rb', line 242 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @channel.nil? invalid_properties.push('invalid value for "channel", channel cannot be nil.') end if @is_test.nil? invalid_properties.push('invalid value for "is_test", is_test cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
407 408 409 |
# File 'lib/norbelys/models/outbound_message.rb', line 407 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/norbelys/models/outbound_message.rb', line 413 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
401 402 403 |
# File 'lib/norbelys/models/outbound_message.rb', line 401 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/norbelys/models/outbound_message.rb', line 266 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @channel.nil? channel_validator = EnumAttributeValidator.new('String', ["email", "call", "sms", "linkedin"]) return false unless channel_validator.valid?(@channel) return false if @is_test.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["queued", "sent", "delivered", "failed", "bounced", "cancelled"]) return false unless status_validator.valid?(@status) true end |