Class: Norbelys::PersonListItem
- Inherits:
-
Object
- Object
- Norbelys::PersonListItem
- Defined in:
- lib/norbelys/models/person_list_item.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#archived_at ⇒ Object
Returns the value of attribute archived_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#email ⇒ Object
Returns the value of attribute email.
-
#email_domain ⇒ Object
Returns the value of attribute email_domain.
-
#family_name ⇒ Object
Returns the value of attribute family_name.
-
#given_name ⇒ Object
Returns the value of attribute given_name.
-
#id ⇒ Object
The person id.
-
#import_id ⇒ Object
Returns the value of attribute import_id.
-
#last_activity_at ⇒ Object
Returns the value of attribute last_activity_at.
-
#object ⇒ Object
Returns the value of attribute object.
-
#score ⇒ Object
Returns the value of attribute score.
-
#source ⇒ Object
Where the person came from:
csv_import,manual,api,form,inbound,integration. -
#status ⇒ Object
Lifecycle status:
active,replied,bounced,unsubscribed,finished. -
#telephone ⇒ Object
Returns the value of attribute telephone.
-
#telephones ⇒ Object
Returns the value of attribute telephones.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PersonListItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PersonListItem
Initializes the object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/norbelys/models/person_list_item.rb', line 150 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Norbelys::PersonListItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Norbelys::PersonListItem`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'archived_at') self.archived_at = attributes[:'archived_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'custom_fields') if (value = attributes[:'custom_fields']).is_a?(Hash) self.custom_fields = value end else self.custom_fields = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'email_domain') self.email_domain = attributes[:'email_domain'] else self.email_domain = nil end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] else self.family_name = nil end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] else self.given_name = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'import_id') self.import_id = attributes[:'import_id'] else self.import_id = nil end if attributes.key?(:'last_activity_at') self.last_activity_at = attributes[:'last_activity_at'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'score') self.score = attributes[:'score'] else self.score = nil end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'telephone') self.telephone = attributes[:'telephone'] else self.telephone = nil end if attributes.key?(:'telephones') if (value = attributes[:'telephones']).is_a?(Array) self.telephones = value end else self.telephones = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#archived_at ⇒ Object
Returns the value of attribute archived_at.
18 19 20 |
# File 'lib/norbelys/models/person_list_item.rb', line 18 def archived_at @archived_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
20 21 22 |
# File 'lib/norbelys/models/person_list_item.rb', line 20 def created_at @created_at end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
22 23 24 |
# File 'lib/norbelys/models/person_list_item.rb', line 22 def custom_fields @custom_fields end |
#email ⇒ Object
Returns the value of attribute email.
24 25 26 |
# File 'lib/norbelys/models/person_list_item.rb', line 24 def email @email end |
#email_domain ⇒ Object
Returns the value of attribute email_domain.
26 27 28 |
# File 'lib/norbelys/models/person_list_item.rb', line 26 def email_domain @email_domain end |
#family_name ⇒ Object
Returns the value of attribute family_name.
28 29 30 |
# File 'lib/norbelys/models/person_list_item.rb', line 28 def family_name @family_name end |
#given_name ⇒ Object
Returns the value of attribute given_name.
30 31 32 |
# File 'lib/norbelys/models/person_list_item.rb', line 30 def given_name @given_name end |
#id ⇒ Object
The person id.
33 34 35 |
# File 'lib/norbelys/models/person_list_item.rb', line 33 def id @id end |
#import_id ⇒ Object
Returns the value of attribute import_id.
35 36 37 |
# File 'lib/norbelys/models/person_list_item.rb', line 35 def import_id @import_id end |
#last_activity_at ⇒ Object
Returns the value of attribute last_activity_at.
37 38 39 |
# File 'lib/norbelys/models/person_list_item.rb', line 37 def last_activity_at @last_activity_at end |
#object ⇒ Object
Returns the value of attribute object.
39 40 41 |
# File 'lib/norbelys/models/person_list_item.rb', line 39 def object @object end |
#score ⇒ Object
Returns the value of attribute score.
41 42 43 |
# File 'lib/norbelys/models/person_list_item.rb', line 41 def score @score end |
#source ⇒ Object
Where the person came from: csv_import, manual, api, form, inbound, integration.
44 45 46 |
# File 'lib/norbelys/models/person_list_item.rb', line 44 def source @source end |
#status ⇒ Object
Lifecycle status: active, replied, bounced, unsubscribed, finished.
47 48 49 |
# File 'lib/norbelys/models/person_list_item.rb', line 47 def status @status end |
#telephone ⇒ Object
Returns the value of attribute telephone.
49 50 51 |
# File 'lib/norbelys/models/person_list_item.rb', line 49 def telephone @telephone end |
#telephones ⇒ Object
Returns the value of attribute telephones.
51 52 53 |
# File 'lib/norbelys/models/person_list_item.rb', line 51 def telephones @telephones end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
53 54 55 |
# File 'lib/norbelys/models/person_list_item.rb', line 53 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/norbelys/models/person_list_item.rb', line 401 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Norbelys.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/norbelys/models/person_list_item.rb', line 101 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/norbelys/models/person_list_item.rb', line 78 def self.attribute_map { :'archived_at' => :'archivedAt', :'created_at' => :'createdAt', :'custom_fields' => :'customFields', :'email' => :'email', :'email_domain' => :'emailDomain', :'family_name' => :'familyName', :'given_name' => :'givenName', :'id' => :'id', :'import_id' => :'importId', :'last_activity_at' => :'lastActivityAt', :'object' => :'object', :'score' => :'score', :'source' => :'source', :'status' => :'status', :'telephone' => :'telephone', :'telephones' => :'telephones', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/norbelys/models/person_list_item.rb', line 377 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/norbelys/models/person_list_item.rb', line 129 def self.openapi_nullable Set.new([ :'archived_at', :'created_at', :'custom_fields', :'email', :'email_domain', :'family_name', :'given_name', :'import_id', :'last_activity_at', :'object', :'score', :'telephone', :'telephones', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/norbelys/models/person_list_item.rb', line 106 def self.openapi_types { :'archived_at' => :'Object', :'created_at' => :'Object', :'custom_fields' => :'Hash<String, Object>', :'email' => :'String', :'email_domain' => :'String', :'family_name' => :'String', :'given_name' => :'String', :'id' => :'String', :'import_id' => :'String', :'last_activity_at' => :'Object', :'object' => :'Object', :'score' => :'Integer', :'source' => :'String', :'status' => :'String', :'telephone' => :'String', :'telephones' => :'Array<String>', :'updated_at' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/norbelys/models/person_list_item.rb', line 340 def ==(o) return true if self.equal?(o) self.class == o.class && archived_at == o.archived_at && created_at == o.created_at && custom_fields == o.custom_fields && email == o.email && email_domain == o.email_domain && family_name == o.family_name && given_name == o.given_name && id == o.id && import_id == o.import_id && last_activity_at == o.last_activity_at && object == o.object && score == o.score && source == o.source && status == o.status && telephone == o.telephone && telephones == o.telephones && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/norbelys/models/person_list_item.rb', line 472 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
364 365 366 |
# File 'lib/norbelys/models/person_list_item.rb', line 364 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
370 371 372 |
# File 'lib/norbelys/models/person_list_item.rb', line 370 def hash [archived_at, created_at, custom_fields, email, email_domain, family_name, given_name, id, import_id, last_activity_at, object, score, source, status, telephone, telephones, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/norbelys/models/person_list_item.rb', line 262 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @score > 100 invalid_properties.push('invalid value for "score", must be smaller than or equal to 100.') end if @score < 0 invalid_properties.push('invalid value for "score", must be greater than or equal to 0.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
448 449 450 |
# File 'lib/norbelys/models/person_list_item.rb', line 448 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/norbelys/models/person_list_item.rb', line 454 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
442 443 444 |
# File 'lib/norbelys/models/person_list_item.rb', line 442 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/norbelys/models/person_list_item.rb', line 290 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @score > 100 return false if @score < 0 return false if @source.nil? source_validator = EnumAttributeValidator.new('String', ["csv_import", "manual", "api", "form", "inbound", "integration"]) return false unless source_validator.valid?(@source) return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "replied", "bounced", "unsubscribed", "finished"]) return false unless status_validator.valid?(@status) true end |